// #region Copyright
// Copyright ArtfulBits Inc. 2005 - 2010. All rights reserved.
// 
// Use of this code is subject to the terms of our license.
// A copy of the current license can be obtained at any time by e-mailing
// info@artfulbits.com. Re-distribution in any form is strictly
// prohibited. Any infringement will be prosecuted under applicable laws.
// #endregion
package com.artfulbits.aiCharts.Samples;

import com.artfulbits.aiCharts.ChartView;
import com.artfulbits.aiCharts.Base.ChartArea;
import com.artfulbits.aiCharts.Base.ChartPoint;
import com.artfulbits.aiCharts.Base.ChartSeries;
import com.artfulbits.aiCharts.Base.ChartAxis.LabelsMode;

import android.app.Activity;
import android.app.AlertDialog;
import android.app.Dialog;
import android.app.AlertDialog.Builder;
import android.os.Bundle;
import android.view.Menu;
import android.view.MenuItem;

public class MainActivity extends Activity
{
	private final static int ABOUT_ITEM_ID = 1;

	/** Called when the activity is first created. */
	@Override
	public void onCreate(Bundle savedInstanceState)
	{
		super.onCreate(savedInstanceState);

		float[] values = new float[]{ 30, 20, 50, 80, 60, 40, 33, 88 };
		String[] labels = new String[]{ "Career", "Money", "Health", "Freands & Family", 
				"Romance", "Personal Growth", "Fun & Recreation", "Physical Enviroment" };
		
		ChartView chartView = new ChartView(this);
		ChartSeries series = new ChartSeries("rose", CustomRoseType.Instance);
		ChartArea area = new ChartArea();
		
		// Use point labels for axis
		area.getDefaultXAxis().setLabelsMode(LabelsMode.SeriesLabels);

		// Define axis ranges (we know what we need).
		area.getDefaultXAxis().getScale().setInterval(1d);
		area.getDefaultXAxis().getScale().setRange(0, values.length);
		
		area.getDefaultYAxis().getScale().setRange(0, 100);

		for (int i = 0; i < values.length; i++)
		{
			ChartPoint point = new ChartPoint(i, values[i]);
			point.setAxisLabel(labels[i]);
			series.getPoints().add(point);
		}
		
		chartView.getSeries().add(series);
		chartView.getAreas().add(area);
		
		setContentView(chartView);
	}
	
	@Override
	public boolean onCreateOptionsMenu(Menu menu)
	{
		menu.add(0, ABOUT_ITEM_ID, 0, getString(R.string.about_menu_item_title));
		return super.onCreateOptionsMenu(menu);
	}
	
	/*
	 * (non-Javadoc)
	 * 
	 * @see android.app.Activity#onOptionsItemSelected(android.view.MenuItem)
	 */
	@Override
	public boolean onOptionsItemSelected(MenuItem item)
	{
		if(item.getItemId() == ABOUT_ITEM_ID)
		{
			showDialog(ABOUT_ITEM_ID);
			return true;
		}
		return super.onOptionsItemSelected(item);
	}
	
	/*
	 * (non-Javadoc)
	 * 
	 * @see android.app.Activity#onCreateDialog(int)
	 */
	@Override
	protected Dialog onCreateDialog(int id)
	{
		Dialog result = null;
		Builder builder;
		
		switch(id)
		{
			case ABOUT_ITEM_ID:
				builder = new AlertDialog.Builder(this);
				
				builder.setTitle(R.string.about_menu_item_title);
				builder.setMessage(R.string.dlg_about_msg);
				
				builder.setPositiveButton(R.string.dlg_ok_btn_title, null);
				
				result = builder.create();
				break;
			
			default:
				result = super.onCreateDialog(id);
				break;
		}
		
		return result;
	}
}
