// #region Copyright
// Copyright ArtfulBits Inc. 2005 - 2010. All rights reserved.
// 
// Use of this code is subject to the terms of our license.
// A copy of the current license can be obtained at any time by e-mailing
// info@artfulbits.com. Re-distribution in any form is strictly
// prohibited. Any infringement will be prosecuted under applicable laws.
// #endregion
package aiCharts.webChart;

import java.io.IOException;
import java.io.OutputStream;

import android.app.Activity;
import android.app.AlertDialog;
import android.app.Dialog;
import android.app.AlertDialog.Builder;
import android.os.Bundle;
import android.view.Menu;
import android.view.MenuItem;
import android.view.ViewGroup.LayoutParams;
import android.webkit.WebView;

import com.artfulbits.aiCharts.Base.ChartArea;
import com.artfulbits.aiCharts.Base.ChartEngine;
import com.artfulbits.aiCharts.Base.ChartSeries;

public class webChartActivity extends Activity
{
	private final static int ABOUT_ITEM_ID = 1;
	
	/** Called when the activity is first created. */
	@Override
	public void onCreate(Bundle savedInstanceState)
	{
		super.onCreate(savedInstanceState);
		
		ChartEngine chart = createChart();
		
		try
		{
			OutputStream stream = openFileOutput("chart.png", MODE_WORLD_WRITEABLE);
			
			chart.save(stream);
			
			stream.flush();
			stream.close();
			
			final String mimetype = "text/html";
			final String encoding = "UTF-8";
			
			String filePath = LocalFileContentProvider.constructUri("chart.png");
			StringBuilder htmldata = new StringBuilder();
			
			htmldata.append("<html><body style='background:black;color:white'>");
			htmldata.append("<div><center><img src=\"" + filePath
					+ "\"/></center></div>");
			htmldata.append(getString(R.string.description));
			htmldata.append("</body></html>");
			
			WebView webView = new WebView(this);
			webView.setLayoutParams(new LayoutParams(LayoutParams.FILL_PARENT,
					LayoutParams.FILL_PARENT));
			
			webView.loadDataWithBaseURL("http:\\aiChartImage.com", htmldata
					.toString(), mimetype, encoding, "");
			setContentView(webView);
		}
		catch(IOException e)
		{
			e.printStackTrace();
		}
	}
	
	private ChartEngine createChart()
	{
		ChartEngine chart = new ChartEngine();
		ChartArea area = new ChartArea();
		ChartSeries series = new ChartSeries();
		
		for(int i = 0; i < 10; i++)
		{
			series.getPoints().addXY(i, 2 + i);
		}
		
		chart.getSeries().add(series);
		chart.getAreas().add(area);
		chart.setBounds(200, 300);
		
		return chart;
	}
	
	@Override
	public boolean onCreateOptionsMenu(Menu menu)
	{
		menu.add(0, ABOUT_ITEM_ID, 0, getString(R.string.about_menu_item_title));
		return super.onCreateOptionsMenu(menu);
	}
	
	@Override
	public boolean onOptionsItemSelected(MenuItem item)
	{
		if(item.getItemId() == ABOUT_ITEM_ID)
		{
			showDialog(ABOUT_ITEM_ID);
			return true;
		}
		return super.onOptionsItemSelected(item);
	}
	
	/*
	 * (non-Javadoc)
	 * 
	 * @see android.app.Activity#onCreateDialog(int)
	 */
	@Override
	protected Dialog onCreateDialog(int id)
	{
		Dialog result = null;
		Builder builder;
		
		switch(id)
		{
			case ABOUT_ITEM_ID:
				builder = new AlertDialog.Builder(this);
				
				builder.setTitle(R.string.about_menu_item_title);
				builder.setMessage(R.string.dlg_about_msg);
				
				builder.setPositiveButton(R.string.dlg_ok_btn_title, null);
				
				result = builder.create();
				break;
			
			default:
				result = super.onCreateDialog(id);
				break;
		}
		
		return result;
	}
}
