// #region Copyright
// Copyright ArtfulBits Inc. 2005 - 2010. All rights reserved.
// 
// Use of this code is subject to the terms of our license.
// A copy of the current license can be obtained at any time by e-mailing
// info@artfulbits.com. Re-distribution in any form is strictly
// prohibited. Any infringement will be prosecuted under applicable laws.
// #endregion
package aiCharts.AnnotationsSample;

import java.util.Random;

import android.app.Activity;
import android.app.AlertDialog;
import android.app.Dialog;
import android.app.AlertDialog.Builder;
import android.graphics.Color;
import android.graphics.drawable.ShapeDrawable;
import android.graphics.drawable.shapes.OvalShape;
import android.os.Bundle;
import android.view.Menu;
import android.view.MenuItem;

import com.artfulbits.aiCharts.ChartView;
import com.artfulbits.aiCharts.Annotations.ChartAnnotationPosition;
import com.artfulbits.aiCharts.Annotations.ChartTextAnnotation;
import com.artfulbits.aiCharts.Base.ChartLegend;
import com.artfulbits.aiCharts.Base.ChartPointCollection;
import com.artfulbits.aiCharts.Base.ChartSeries;
import com.artfulbits.aiCharts.Base.LegendItemsProvider;
import com.artfulbits.aiCharts.Enums.Alignment;
import com.artfulbits.aiCharts.Types.ChartTypes;

public class AnnotationsSample extends Activity
{
	private final static int LETTERS_ASCII_OFFSET = 65;
	private final static int ABOUT_ITEM_ID = 1;
	private final static String[] s_annotationsDescripton = new String[]{
			"Paleozoic","Triassic","Jurrasic","Cretaceous","Cenozoic","Stereozoic"};
	
	/** Called when the activity is first created. */
	@Override
	public void onCreate(Bundle savedInstanceState)
	{
		super.onCreate(savedInstanceState);
		setContentView(R.layout.main);
		final ChartView view = (ChartView)findViewById(R.id.chartView);
		view.addArea();
		
		ChartSeries series = new ChartSeries("Series1", ChartTypes.Line);
		view.getSeries().add(series);
		ChartPointCollection points = series.getPoints();
		Random r = new Random();
		for(int i = 0; i < 30; i++)
		{
			points.addXY(i, r.nextInt(100));
		}
		// Creating drawable that is used to draw annotation's background.
		ShapeDrawable annotationBackground = new ShapeDrawable(new OvalShape());
		annotationBackground.getPaint().setColor(Color.LTGRAY);
		// Adding annotation for each 5th point of series.
		for(int i = 0; i < 30; i += 5)
		{
			// Marking annotation with letters A-Z.
			ChartTextAnnotation a = new ChartTextAnnotation(annotationBackground,
					String.valueOf((char)(i / 5 + LETTERS_ASCII_OFFSET)),
					s_annotationsDescripton[i / 5]);
			// Setting annotation offset to 10 px.  
			a.setOffset(10);
			// Aligning annotation above the corresponding point.
			a.setAlignment(Alignment.Center, Alignment.Far);
			// Binding annotation with Series1 series and specifying series point index.
			a.setPosition(ChartAnnotationPosition. relativeToSeries("Series1", i));
			// Adding annotation to chart's annotations collection.
			view.getChart().getAnnotations().add(a);
		}
		
		view.getLegends().add(
				new ChartLegend(new LegendItemsProvider.AnnotationItemsProvider()));
	}
	
	/* (non-Javadoc)
	 * @see android.app.Activity#onCreateOptionsMenu(android.view.Menu)
	 */
	@Override
	public boolean onCreateOptionsMenu( Menu menu )
	{
		menu.add( 0, ABOUT_ITEM_ID, 0, getString( R.string.about_menu_item_title ) );
		return super.onCreateOptionsMenu( menu );
	}

	/* (non-Javadoc)
	 * @see android.app.Activity#onCreateDialog(int)
	 */
	@Override
	protected Dialog onCreateDialog( int id )
	{
		Dialog result = null;
		Builder builder;

		switch( id )
		{
			case ABOUT_ITEM_ID:
				builder = new AlertDialog.Builder( this );

				builder.setTitle( R.string.about_menu_item_title );
				builder.setMessage( R.string.dlg_about_msg );

				builder.setPositiveButton( R.string.dlg_ok_btn_title, null);

				result = builder.create();
				break;

			default:
				result = super.onCreateDialog( id );
				break;
		}

		return result;
	}

	/* (non-Javadoc)
	 * @see android.app.Activity#onMenuItemSelected(int, android.view.MenuItem)
	 */
	@Override
	public boolean onMenuItemSelected( int featureId, MenuItem item )
	{
		switch( item.getItemId() )
		{
			case ABOUT_ITEM_ID:
				showDialog( ABOUT_ITEM_ID );
				return true;

			default:
				return false;
		}
	}
}
