// #region Copyright
// Copyright ArtfulBits Inc. 2005 - 2010. All rights reserved.
// 
// Use of this code is subject to the terms of our license.
// A copy of the current license can be obtained at any time by e-mailing
// info@artfulbits.com. Re-distribution in any form is strictly
// prohibited. Any infringement will be prosecuted under applicable laws.
// #endregion
package aiCharts.dateTimeChart;

import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.GregorianCalendar;
import java.util.Random;

import android.app.Activity;
import android.app.AlertDialog;
import android.app.Dialog;
import android.app.AlertDialog.Builder;
import android.os.Bundle;
import android.view.Menu;
import android.view.MenuItem;
import android.view.View;
import android.widget.Button;

import com.artfulbits.aiCharts.*;
import com.artfulbits.aiCharts.Base.*;
import com.artfulbits.aiCharts.Base.ChartAxis.LabelsMode;
import com.artfulbits.aiCharts.Types.*;

public class aiChartDateTime extends Activity
{
	private final static int ABOUT_ITEM_ID = 1;
	
	/** Called when the activity is first created. */
	@Override
	public void onCreate(Bundle savedInstanceState)
	{
		super.onCreate(savedInstanceState);
		setContentView(R.layout.main);
		ChartView chart = (ChartView)findViewById(R.id.chart);
		Button actionButton = (Button)findViewById(R.id.rangeLabelsButton);
		final ChartArea area = new ChartArea();
		actionButton.setOnClickListener(new View.OnClickListener()
		{
			public void onClick(View v)
			{
				Button sender = (Button)v;
				
				if(sender.getText().equals(getString(R.string.range_labels_btn_title)))
				{
					area.getDefaultXAxis().setLabelsMode(LabelsMode.RangeLabels);
					sender.setText(R.string.series_labels_btn_title);
				}
				else
				{
					area.getDefaultXAxis().setLabelsMode(LabelsMode.SeriesLabels);
					sender.setText(R.string.range_labels_btn_title);
				}
			}
		});
		
		ChartSeries series1 = new ChartSeries("Series 1", ChartTypes.SplineArea);
		ChartSeries series2 = new ChartSeries("Series 2", ChartTypes.SplineArea);
		
		ChartPointCollection series1Points = series1.getPoints();
		ChartPointCollection series2Points = series2.getPoints();
		// Getting current time
		Date xDate = GregorianCalendar.getInstance().getTime();
		Random r = new Random();
		for(int i = 0; i < 4; i++)
		{
			xDate.setMonth(i);
			series1Points.addDate(xDate, r.nextDouble());
			series2Points.addDate(xDate, r.nextDouble());
		}
		
		chart.getAreas().add(area);
		chart.getSeries().add(series1);
		chart.getSeries().add(series2);
		series1.setArea(area.getName());
		series2.setArea(area.getName());
		ChartAxis axis = area.getDefaultXAxis();
		axis.setFormat(new SimpleDateFormat("MMM, dd"));
		axis.setValueType(ChartAxis.ValueType.Date);
		axis.setLabelsMode(LabelsMode.SeriesLabels);
	}
	
	/*
	 * (non-Javadoc)
	 * 
	 * @see android.app.Activity#onCreateOptionsMenu(android.view.Menu)
	 */
	@Override
	public boolean onCreateOptionsMenu(Menu menu)
	{
		menu.add(0, ABOUT_ITEM_ID, 0, getString(R.string.about_menu_item_title));
		return super.onCreateOptionsMenu(menu);
	}
	
	/*
	 * (non-Javadoc)
	 * 
	 * @see android.app.Activity#onOptionsItemSelected(android.view.MenuItem)
	 */
	@Override
	public boolean onOptionsItemSelected(MenuItem item)
	{
		if(item.getItemId() == ABOUT_ITEM_ID)
		{
			showDialog(ABOUT_ITEM_ID);
			return true;
		}
		return super.onOptionsItemSelected(item);
	}
	
	/*
	 * (non-Javadoc)
	 * 
	 * @see android.app.Activity#onCreateDialog(int)
	 */
	@Override
	protected Dialog onCreateDialog(int id)
	{
		Dialog result = null;
		Builder builder;
		
		switch(id)
		{
			case ABOUT_ITEM_ID:
				builder = new AlertDialog.Builder(this);
				
				builder.setTitle(R.string.about_menu_item_title);
				builder.setMessage(R.string.dlg_about_msg);
				
				builder.setPositiveButton(R.string.dlg_ok_btn_title, null);
				
				result = builder.create();
				break;
			
			default:
				result = super.onCreateDialog(id);
				break;
		}
		
		return result;
	}
}
