// #region Copyright
// Copyright ArtfulBits Inc. 2005 - 2010. All rights reserved.
// 
// Use of this code is subject to the terms of our license.
// A copy of the current license can be obtained at any time by e-mailing
// info@artfulbits.com. Re-distribution in any form is strictly
// prohibited. Any infringement will be prosecuted under applicable laws.
// #endregion
package aiCharts.fromXmlSource;

import java.io.IOException;

import javax.xml.parsers.DocumentBuilder;
import javax.xml.parsers.DocumentBuilderFactory;
import javax.xml.parsers.ParserConfigurationException;

import org.w3c.dom.Document;
import org.xml.sax.SAXException;

import android.app.Activity;
import android.app.AlertDialog;
import android.app.Dialog;
import android.app.AlertDialog.Builder;
import android.os.Bundle;
import android.view.Menu;
import android.view.MenuItem;

import com.artfulbits.aiCharts.*;
import com.artfulbits.aiCharts.Base.*;
import com.artfulbits.aiCharts.Types.*;

public class aiChartFromXmlSource extends Activity
{
	private final static int ABOUT_ITEM_ID = 1;
	
	/** Called when the activity is first created. */
	@Override
	public void onCreate(Bundle savedInstanceState)
	{
		super.onCreate(savedInstanceState);
		setContentView(R.layout.main);
		ChartView chart = (ChartView)findViewById(R.id.chart);
		
		ChartArea area = new ChartArea();
		ChartSeries series1 = new ChartSeries("Series 1", ChartTypes.FastLine);
		ChartSeries series2 = new ChartSeries("Series 2", ChartTypes.FastLine);
		// caching series points for performance considerations.
		ChartPointCollection series1Points = series1.getPoints();
		ChartPointCollection series2Points = series2.getPoints();
		
		// Creating DOM XML element to pass it to series.
		DocumentBuilderFactory dbf = DocumentBuilderFactory.newInstance();
		Document dom1 = null;
		Document dom2 = null;
		try
		{
			
			// Using factory get an instance of document builder
			DocumentBuilder db = dbf.newDocumentBuilder();
			
			// parse using builder to get DOM representation of the XML file from
			// assests.
			dom1 = db.parse(this.getAssets().open("data_by_attributes.xml"));
			dom2 = db.parse(this.getAssets().open("data_by_elements.xml"));
			
		}
		catch(ParserConfigurationException pce)
		{
			pce.printStackTrace();
		}
		catch(SAXException se)
		{
			se.printStackTrace();
		}
		catch(IOException ioe)
		{
			ioe.printStackTrace();
		}
		
		// setting series data for attributed xml points and nested in tree xml
		// points.
		
		series1Points.setData(dom1.getDocumentElement(), true, "X", "Y1");
		series2Points.setData(dom2.getDocumentElement(), false, "X", "Y");
		
		chart.getAreas().add(area);
		chart.getSeries().add(series1);
		chart.getSeries().add(series2);
		series1.setArea(area.getName());
		series2.setArea(area.getName());
	}
	
	/*
	 * (non-Javadoc)
	 * 
	 * @see android.app.Activity#onCreateOptionsMenu(android.view.Menu)
	 */
	@Override
	public boolean onCreateOptionsMenu(Menu menu)
	{
		menu.add(0, ABOUT_ITEM_ID, 0, getString(R.string.about_menu_item_title));
		return super.onCreateOptionsMenu(menu);
	}
	
	/*
	 * (non-Javadoc)
	 * 
	 * @see android.app.Activity#onOptionsItemSelected(android.view.MenuItem)
	 */
	@Override
	public boolean onOptionsItemSelected(MenuItem item)
	{
		if(item.getItemId() == ABOUT_ITEM_ID)
		{
			showDialog(ABOUT_ITEM_ID);
			return true;
		}
		return super.onOptionsItemSelected(item);
	}
	
	/*
	 * (non-Javadoc)
	 * 
	 * @see android.app.Activity#onCreateDialog(int)
	 */
	@Override
	protected Dialog onCreateDialog(int id)
	{
		Dialog result = null;
		Builder builder;
		
		switch(id)
		{
			case ABOUT_ITEM_ID:
				builder = new AlertDialog.Builder(this);
				
				builder.setTitle(R.string.about_menu_item_title);
				builder.setMessage(R.string.dlg_about_msg);
				
				builder.setPositiveButton(R.string.dlg_ok_btn_title, null);
				
				result = builder.create();
				break;
			
			default:
				result = super.onCreateDialog(id);
				break;
		}
		
		return result;
	}
}
