// #region Copyright
// Copyright ArtfulBits Inc. 2005 - 2010. All rights reserved.
// 
// Use of this code is subject to the terms of our license.
// A copy of the current license can be obtained at any time by e-mailing
// info@artfulbits.com. Re-distribution in any form is strictly
// prohibited. Any infringement will be prosecuted under applicable laws.
// #endregion
package aiCharts.GallerySample;

import com.artfulbits.aiCharts.ChartView;
import com.artfulbits.aiCharts.Base.ChartNamedCollection;
import com.artfulbits.aiCharts.Base.ChartSeries;
import com.artfulbits.aiCharts.Base.ChartType;
import com.artfulbits.aiCharts.Types.ChartTypes;

import android.app.Activity;
import android.app.AlertDialog;
import android.app.Dialog;
import android.app.AlertDialog.Builder;
import android.os.Bundle;
import android.view.Menu;
import android.view.MenuItem;

public class ChartActivity extends Activity
{
	// #region Members
	private final static int ABOUT_ITEM_ID = 1;
	
	private static final double[] sPoints1 = new double[]{1,5,3,7,2,4,7,4,9,1,0};
	
	private static final double[] sPoints2 = new double[]{3,4,1,8,4,9,2,5,1,7,7};
	
	private static final double[] sPoints3 = new double[]{5,8,2,9,6,1,4,2,8,7,4};
	
	// #endregion
	
	// #region Public methods
	@Override
	protected void onCreate(Bundle savedInstanceState)
	{
		
		// TODO Auto-generated method stub
		super.onCreate(savedInstanceState);
		setContentView(R.layout.main);
		ChartView chartView = (ChartView)findViewById(R.id.chartView);
		
		Bundle extras = getIntent().getExtras();
		int chartTypeIndex = extras.getInt(GallerySample.EXT_CHART_TYPE);
		ChartType type = ChartTypes.getTypes()[chartTypeIndex];
		
		switch(type.getRequiredUsages().length)
		{
			case 2:
				createChartMode2(chartView, type);
				break;
			case 4:
				createChartMode4(chartView, type);
				break;
			default:
				createChartMode1(chartView, type);
				break;
		}
	}
	
	@Override
	public boolean onCreateOptionsMenu(Menu menu)
	{
		menu.add(0, ABOUT_ITEM_ID, 0, getString(R.string.about_menu_item_title));
		return super.onCreateOptionsMenu(menu);
	}
	
	@Override
	protected Dialog onCreateDialog(int id)
	{
		Dialog result = null;
		Builder builder;
		
		switch(id)
		{
			case ABOUT_ITEM_ID:
				builder = new AlertDialog.Builder(this);
				
				builder.setTitle(R.string.about_menu_item_title);
				builder.setMessage(R.string.dlg_about_msg);
				
				builder.setPositiveButton(R.string.dlg_ok_btn_title, null);
				
				result = builder.create();
				break;
			
			default:
				result = super.onCreateDialog(id);
				break;
		}
		
		return result;
	}
	
	@Override
	public boolean onMenuItemSelected(int featureId, MenuItem item)
	{
		switch(item.getItemId())
		{
			case ABOUT_ITEM_ID:
				showDialog(ABOUT_ITEM_ID);
				return true;
				
			default:
				return false;
		}
	}
	
	// #endregion
	
	// #region Protected methods
	protected void createChartMode1(ChartView chartView, ChartType type)
	{
		ChartNamedCollection<ChartSeries> seriesCollection = chartView.getSeries();
		
		ChartSeries series1;
		series1 = new ChartSeries("Series1", type);
		series1.getPoints().setData(sPoints1);
		
		ChartSeries series2;
		series2 = new ChartSeries("Series2", type);
		series2.getPoints().setData(sPoints2);
		
		ChartSeries series3;
		series3 = new ChartSeries("Series3", type);
		series3.getPoints().setData(sPoints3);
		
		seriesCollection.add(series1);
		seriesCollection.add(series2);
		seriesCollection.add(series3);
	}
	
	protected void createChartMode2(ChartView chartView, ChartType type)
	{
		ChartNamedCollection<ChartSeries> seriesCollection = chartView.getSeries();
		
		ChartSeries series1;
		series1 = new ChartSeries("Series1", type);
		series1.getPoints().addXY(1, 2, 1);
		series1.getPoints().addXY(2, 3, 4);
		series1.getPoints().addXY(3, 5, 3);
		series1.getPoints().addXY(4, 8, 5);
		series1.getPoints().addXY(5, 2, 9);
		series1.getPoints().addXY(6, 7, 2);
		
		seriesCollection.add(series1);
	}
	
	protected void createChartMode4(ChartView chartView, ChartType type)
	{
		ChartNamedCollection<ChartSeries> seriesCollection = chartView.getSeries();
		
		ChartSeries series1;
		series1 = new ChartSeries("Series1", type);
		series1.getPoints().addXY(1, 10, 26, 15, 20);
		series1.getPoints().addXY(2, 11, 30, 16, 22);
		series1.getPoints().addXY(3, 15, 34, 19, 30);
		series1.getPoints().addXY(4, 10, 27, 13, 25);
		series1.getPoints().addXY(5, 10, 26, 15, 20);
		series1.getPoints().addXY(6, 7, 24, 11, 19);
		
		seriesCollection.add(series1);
	}
	// #endregion
}
