// #region Copyright
// Copyright ArtfulBits Inc. 2005 - 2010. All rights reserved.
// 
// Use of this code is subject to the terms of our license.
// A copy of the current license can be obtained at any time by e-mailing
// info@artfulbits.com. Re-distribution in any form is strictly
// prohibited. Any infringement will be prosecuted under applicable laws.
// #endregion
package com.aiCharts.PieSampleAdv;

import android.app.Activity;
import android.app.AlertDialog;
import android.app.Dialog;
import android.app.AlertDialog.Builder;
import android.os.Bundle;
import android.os.Handler;
import android.os.SystemClock;
import android.view.Menu;
import android.view.MenuItem;
import android.view.MotionEvent;
import android.view.View;
import android.view.View.OnTouchListener;

import com.artfulbits.aiCharts.ChartView;
import com.artfulbits.aiCharts.Base.ChartArea;
import com.artfulbits.aiCharts.Base.ChartSeries;
import com.artfulbits.aiCharts.Types.ChartPieType;
import com.artfulbits.aiCharts.Types.ChartTypes;

public class PieSampleAdvActivity extends Activity
{
	private final static int ABOUT_ITEM_ID = 1;
	private final static int ANIMATION_ITEM_ID = 0;

	ChartView m_chartView;
	boolean m_animated = false;
	Handler m_animationHandler = new Handler();

	/** Called when the activity is first created. */
	@Override
	public void onCreate(Bundle savedInstanceState)
	{
		super.onCreate(savedInstanceState);

		m_chartView = new ChartView(this);

		ChartSeries series1 = new ChartSeries("PieChart", ChartTypes.Pie);

		for (int i = 0; i < 10; i++)
		{
			series1.getPoints().addXY(i, 100 * i);
		}

		series1.setShowLabel(true);
		series1.setAttribute(ChartPieType.LABEL_STYLE,
				ChartPieType.LabelStyle.OutsideColumn);

		m_chartView.setBackgroundResource(android.R.drawable.alert_dark_frame);
		m_chartView.getSeries().add(series1);
		m_chartView.getAreas().add(new ChartArea());
		m_chartView.setOnTouchListener(new OnTouchListener()
		{
			@Override
			public boolean onTouch(View v, MotionEvent event)
			{
				if (event.getAction() == MotionEvent.ACTION_MOVE)
				{
					int cX = (v.getLeft() + v.getRight()) / 2;
					int cY = (v.getTop() + v.getBottom()) / 2;

					int angle = (int) Math.toDegrees(Math.atan2(event.getY() - cY,
							event.getX() - cX));

					m_chartView.getSeries().get(0).setAttribute(
							ChartPieType.ANGLE_OFFSET, angle);
				}

				return true;
			}
		});

		setContentView(m_chartView);
	}

	@Override
	public boolean onCreateOptionsMenu(Menu menu)
	{
		menu.add(0, ANIMATION_ITEM_ID, 0,
				getString(R.string.animation_menu_item_title));
		menu.add(0, ABOUT_ITEM_ID, 0, getString(R.string.about_menu_item_title));

		return super.onCreateOptionsMenu(menu);
	}

	@Override
	public boolean onOptionsItemSelected(MenuItem item)
	{
		if (item.getItemId() == ANIMATION_ITEM_ID)
		{
			m_animated = !m_animated;

			if (m_animated)
			{
				m_animationHandler.postDelayed(new Runnable()
				{
					long m_lastTime = SystemClock.elapsedRealtime();

					@Override
					public void run()
					{
						if(m_animated)
						{
							int angle = m_chartView.getSeries().get(0).getAttribute(
									ChartPieType.ANGLE_OFFSET);
							long lastTime = SystemClock.elapsedRealtime();
	
							angle += (lastTime - m_lastTime) / 30;
	
							m_chartView.getSeries().get(0).setAttribute(
									ChartPieType.ANGLE_OFFSET, angle);
							m_lastTime = lastTime;
							m_animationHandler.postDelayed(this, 100);
						}
					}
				}, 0);
			}

			return true;
		}
		else if (item.getItemId() == ABOUT_ITEM_ID)
		{
			showDialog(ABOUT_ITEM_ID);
		}

		return super.onOptionsItemSelected(item);
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see android.app.Activity#onCreateDialog(int)
	 */
	@Override
	protected Dialog onCreateDialog(int id)
	{
		Dialog result = null;
		Builder builder;

		switch (id)
		{
			case ABOUT_ITEM_ID:
				builder = new AlertDialog.Builder(this);

				builder.setTitle(R.string.about_menu_item_title);
				builder.setMessage(R.string.dlg_about_msg);

				builder.setPositiveButton(R.string.dlg_ok_btn_title, null);

				result = builder.create();
			break;

			default:
				result = super.onCreateDialog(id);
			break;
		}

		return result;
	}
}
