// #region Copyright
// Copyright ArtfulBits Inc. 2005 - 2010. All rights reserved.
// 
// Use of this code is subject to the terms of our license.
// A copy of the current license can be obtained at any time by e-mailing
// info@artfulbits.com. Re-distribution in any form is strictly
// prohibited. Any infringement will be prosecuted under applicable laws.
// #endregion
package aiCharts.realtimeChart;

import java.util.Random;

import com.artfulbits.aiCharts.ChartView;

import android.app.Activity;
import android.app.AlertDialog;
import android.app.Dialog;
import android.app.AlertDialog.Builder;
import android.os.Bundle;
import android.os.Handler;
import android.view.Menu;
import android.view.MenuItem;

import com.artfulbits.aiCharts.Base.ChartArea;
import com.artfulbits.aiCharts.Base.ChartAxisScale;
import com.artfulbits.aiCharts.Base.ChartPoint;
import com.artfulbits.aiCharts.Base.ChartPointCollection;
import com.artfulbits.aiCharts.Base.ChartSeries;
import com.artfulbits.aiCharts.Types.ChartTypes;

public class RealtimeChart extends Activity
{
	private final static int ABOUT_ITEM_ID = 1;
	
	// #region Nested types
	class AddPointTask implements Runnable
	{
		// #region Members
		private ChartPointCollection m_targetCollection;
		
		private Random m_randomValuesGenerator;
		
		private int m_pointsCounter;
		
		private final int m_maxPoints = 50;
		
		private final long m_dellay = 100;
		
		// #endregion
		
		// #region Constructor
		public AddPointTask(ChartSeries series)
		{
			m_randomValuesGenerator = new Random();
			m_targetCollection = series.getPoints();
		}
		
		// #endregion
		
		// #region Public methods
		public void run()
		{
			
			ChartPoint point = new ChartPoint(m_pointsCounter++,
					m_randomValuesGenerator.nextInt(100));
			m_targetCollection.add(point);
			if(m_pointsCounter > m_maxPoints)
			{
				m_targetCollection.removeAt(0);
			}
			m_handler.postDelayed(this, m_dellay);
		}
		// #endregion
	}
	
	// #endregion
	
	// #region Members
	private Handler m_handler = new Handler();
	
	// #endregion
	
	// #region Public methods
	/** Called when the activity is first created. */
	@Override
	public void onCreate(Bundle savedInstanceState)
	{
		super.onCreate(savedInstanceState);
		setContentView(R.layout.main);
		ChartView chartView = (ChartView)findViewById(R.id.chartView);
		
		ChartSeries series = new ChartSeries("FastLineSeries", ChartTypes.FastLine);
		
		chartView.getSeries().add(series);
		ChartArea area = new ChartArea();
		area.getDefaultXAxis().getScale().setMargin(ChartAxisScale.MARGIN_NONE);
		chartView.getAreas().add(area);
		// Because java's Timer class behaves incorrectly,
		// using following workaround.
		m_handler.postDelayed(new AddPointTask(series), 0);
	}
	
	/*
	 * (non-Javadoc)
	 * 
	 * @see android.app.Activity#onCreateOptionsMenu(android.view.Menu)
	 */
	@Override
	public boolean onCreateOptionsMenu(Menu menu)
	{
		menu.add(0, ABOUT_ITEM_ID, 0, getString(R.string.about_menu_item_title));
		return super.onCreateOptionsMenu(menu);
	}
	
	/*
	 * (non-Javadoc)
	 * 
	 * @see android.app.Activity#onOptionsItemSelected(android.view.MenuItem)
	 */
	@Override
	public boolean onOptionsItemSelected(MenuItem item)
	{
		if(item.getItemId() == ABOUT_ITEM_ID)
		{
			showDialog(ABOUT_ITEM_ID);
			return true;
		}
		return super.onOptionsItemSelected(item);
	}
	
	/*
	 * (non-Javadoc)
	 * 
	 * @see android.app.Activity#onCreateDialog(int)
	 */
	@Override
	protected Dialog onCreateDialog(int id)
	{
		Dialog result = null;
		Builder builder;
		
		switch(id)
		{
			case ABOUT_ITEM_ID:
				builder = new AlertDialog.Builder(this);
				
				builder.setTitle(R.string.about_menu_item_title);
				builder.setMessage(R.string.dlg_about_msg);
				
				builder.setPositiveButton(R.string.dlg_ok_btn_title, null);
				
				result = builder.create();
				break;
			
			default:
				result = super.onCreateDialog(id);
				break;
		}
		
		return result;
	}
	// #endregion
}
