// #region Copyright
// Copyright ArtfulBits Inc. 2005 - 2010. All rights reserved.
// 
// Use of this code is subject to the terms of our license.
// A copy of the current license can be obtained at any time by e-mailing
// info@artfulbits.com. Re-distribution in any form is strictly
// prohibited. Any infringement will be prosecuted under applicable laws.
// #endregion
package aiCharts.stackedColumn;

import android.app.Activity;
import android.app.AlertDialog;
import android.app.Dialog;
import android.app.AlertDialog.Builder;
import android.graphics.Color;
import android.graphics.drawable.Drawable;
import android.os.Bundle;
import android.text.TextPaint;
import android.view.Menu;
import android.view.MenuItem;

import com.artfulbits.aiCharts.*;
import com.artfulbits.aiCharts.Base.*;
import com.artfulbits.aiCharts.Base.ChartAxis.Label;
import com.artfulbits.aiCharts.Base.ChartAxis.LabelsMode;
import com.artfulbits.aiCharts.Base.ChartAxis.TickMarkMode;
import com.artfulbits.aiCharts.Types.*;

public class FancyChart extends Activity
{
	private final static int ABOUT_ITEM_ID = 1;
	
	/** Called when the activity is first created. */
	@Override
	public void onCreate(Bundle savedInstanceState)
	{
		super.onCreate(savedInstanceState);
		setContentView(R.layout.main);
		ChartView chartView = (ChartView)findViewById(R.id.chartView);
		chartView.setBackgroundResource(R.drawable.background);
		ChartAxis[] axes = this.configureData(chartView);
		
		TextPaint axisLabelsPaint = new TextPaint();
		axisLabelsPaint.setColor(Color.BLACK);
		axisLabelsPaint.setDither(false);
		axisLabelsPaint.setAntiAlias(true);
		
		for(ChartAxis axis : axes)
		{
			axis.setLineType(2, Color.BLACK);
			axis.getLabelPaint().set(axisLabelsPaint);
		}
		ConfigureXAxis(axes[0]);
		
		axes[1].setTickMarkMode(TickMarkMode.None);
		
	}
	
	/*
	 * (non-Javadoc)
	 * 
	 * @see android.app.Activity#onCreateOptionsMenu(android.view.Menu)
	 */
	@Override
	public boolean onCreateOptionsMenu(Menu menu)
	{
		menu.add(0, ABOUT_ITEM_ID, 0, getString(R.string.about_menu_item_title));
		return super.onCreateOptionsMenu(menu);
	}
	
	/*
	 * (non-Javadoc)
	 * 
	 * @see android.app.Activity#onOptionsItemSelected(android.view.MenuItem)
	 */
	@Override
	public boolean onOptionsItemSelected(MenuItem item)
	{
		if(item.getItemId() == ABOUT_ITEM_ID)
		{
			showDialog(ABOUT_ITEM_ID);
			return true;
		}
		return super.onOptionsItemSelected(item);
	}
	
	/*
	 * (non-Javadoc)
	 * 
	 * @see android.app.Activity#onCreateDialog(int)
	 */
	@Override
	protected Dialog onCreateDialog(int id)
	{
		Dialog result = null;
		Builder builder;
		
		switch(id)
		{
			case ABOUT_ITEM_ID:
				builder = new AlertDialog.Builder(this);
				
				builder.setTitle(R.string.about_menu_item_title);
				builder.setMessage(R.string.dlg_about_msg);
				
				builder.setPositiveButton(R.string.dlg_ok_btn_title, null);
				
				result = builder.create();
				break;
			
			default:
				result = super.onCreateDialog(id);
				break;
		}
		
		return result;
	}
	
	private ChartAxis[] configureData(ChartView chartView)
	{
		ChartSeries series1 = new ChartSeries("Product A", ChartTypes.StackedColumn);
		ChartSeries series2 = new ChartSeries("Product B", ChartTypes.StackedColumn);
		ChartSeries series3 = new ChartSeries("Product C", ChartTypes.StackedColumn);
		
		Drawable seriesBackground = getResources().getDrawable(R.drawable.series1);
		series1.setBackDrawable(seriesBackground);
		seriesBackground = getResources().getDrawable(R.drawable.series2);
		series2.setBackDrawable(seriesBackground);
		seriesBackground = getResources().getDrawable(R.drawable.series3);
		series3.setBackDrawable(seriesBackground);
		ChartPointCollection series1Points = series1.getPoints();
		ChartPointCollection series2Points = series2.getPoints();
		ChartPointCollection series3Points = series3.getPoints();
		
		series1Points.addXY(0, 4);
		series1Points.addXY(1, 5);
		series1Points.addXY(2, 7);
		series1Points.addXY(3, 2);
		series1Points.addXY(4, 4);
		series1Points.addXY(5, 5);
		series1Points.addXY(6, 4.5);
		
		series2Points.addXY(0, 5);
		series2Points.addXY(1, 4);
		series2Points.addXY(2, 2);
		series2Points.addXY(3, 3);
		series2Points.addXY(4, 5);
		series2Points.addXY(5, 1);
		series2Points.addXY(6, 3);
		
		series3Points.addXY(0, 3);
		series3Points.addXY(1, 2);
		series3Points.addXY(2, 5);
		series3Points.addXY(3, 1);
		series3Points.addXY(4, 7);
		series3Points.addXY(5, 2);
		series3Points.addXY(6, 3);
		ChartArea area = new ChartArea();
		chartView.getAreas().add(area);
		chartView.getSeries().add(series1);
		chartView.getSeries().add(series2);
		chartView.getSeries().add(series3);
		area.getDefaultXAxis().setGridVisible(true);
		return new ChartAxis[]{area.getDefaultXAxis(),area.getDefaultYAxis()};
	}
	
	private void ConfigureXAxis(ChartAxis axis)
	{
		axis.setLineType(2, Color.BLACK);
		axis.setLabelsMode(LabelsMode.NoLabels);
		axis.getScale().setRange(-1, 6.5);
		axis.setGridVisible(false);
		ChartCollection<Label> labels = axis.getCustomLabels();
		String[] months = getResources().getStringArray(R.array.months);
		for(int i = 0; i < months.length; i++)
		{
			labels.add(new Label(months[i], i));
		}
		axis.setTickMarkMode(TickMarkMode.None);
		ChartAxisStripLine stripline = new ChartAxisStripLine(1, 2);
		stripline.setColor(0xFFC1CEE3);
		stripline.setStart(-1);
		axis.getStripLines().add(stripline);
	}
}
