// #region Copyright
// Copyright ArtfulBits Inc. 2005 - 2010. All rights reserved.
// 
// Use of this code is subject to the terms of our license.
// A copy of the current license can be obtained at any time by e-mailing
// info@artfulbits.com. Re-distribution in any form is strictly
// prohibited. Any infringement will be prosecuted under applicable laws.
// #endregion
package aiCharts.systemGraph;

import android.app.Activity;
import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.Intent;
import android.content.IntentFilter;
import android.os.Handler;

import com.artfulbits.aiCharts.Base.ChartSeries;

/**
 * Class extract runtime battery status.
 * 
 * @author Oleksandr Kucherenko
 */
public class BatteryRuntimeValues extends ValuesCollector
{
	/** Known to us keys that we can ask from battery broadcast. */
	private final static String[] BATTERY_KEYS = {"level","scale","voltage",
			"temperature","plugged","status","health","present","technology",
			"icon-small"};
	
	/** Current battery level. */
	protected int mPercent;
	
	/** Current battery voltage state. */
	protected int mVoltage;
	
	/** Current battery temperature state. */
	protected int mTemperature;
	
	/** Broadcast activity reference. Used for register, unregister access. */
	private final Activity mActivity;
	
	/** Receiver that collect broadcasted battery changes. */
	private final BroadcastReceiver mReceiver = new BroadcastReceiver()
	{
		@Override
		public void onReceive(Context context, Intent intent)
		{
			String action = intent.getAction();
			
			if(Intent.ACTION_BATTERY_CHANGED.equals(action))
			{
				int level = intent.getIntExtra(BATTERY_KEYS[0], 0);
				int scale = intent.getIntExtra(BATTERY_KEYS[1], 100);
				
				mPercent = level * 100 / scale;
				mVoltage = intent.getIntExtra(BATTERY_KEYS[2], 0);
				mTemperature = intent.getIntExtra(BATTERY_KEYS[3], 0);
			}
		}
	};
	
	/**
	 * Create Battery runtime values collector.
	 * 
	 * @param activity Activity for broadcast events.
	 * @param handler handler that keep reference on us. Parent object.
	 * @param series Series that we should fill by data.
	 */
	public BatteryRuntimeValues(final Activity activity, final Handler handler,
			final ChartSeries series)
	{
		super(handler, series);
		mActivity = activity;
	}
	
	/*
	 * (non-Javadoc)
	 * 
	 * @see com.artfulbits.system.graph.ValuesCollector#reset()
	 */
	@Override
	public void reset()
	{
		super.reset();
		
		mActivity.registerReceiver(mReceiver, new IntentFilter(
				Intent.ACTION_BATTERY_CHANGED));
	}
	
	/*
	 * (non-Javadoc)
	 * 
	 * @see com.artfulbits.system.graph.ValuesCollector#shutdown()
	 */
	@Override
	public void shutdown()
	{
		super.shutdown();
		
		mActivity.unregisterReceiver(mReceiver);
		mPercent = 0;
		mVoltage = 0;
		mTemperature = 0;
	}
	
	/*
	 * (non-Javadoc)
	 * 
	 * @see com.artfulbits.system.graph.ValuesCollector#getRuntimeValue()
	 */
	@Override
	protected double getRuntimeValue()
	{
		return mPercent;
	}
	
}
