// #region Copyright
// Copyright ArtfulBits Inc. 2005 - 2010. All rights reserved.
// 
// Use of this code is subject to the terms of our license.
// A copy of the current license can be obtained at any time by e-mailing
// info@artfulbits.com. Re-distribution in any form is strictly
// prohibited. Any infringement will be prosecuted under applicable laws.
// #endregion
package aiCharts.systemGraph;

import android.os.Handler;

import com.artfulbits.aiCharts.Base.ChartSeries;

/**
 * Extract memory usage runtime information.
 * 
 * @author Oleksandr Kucherenko
 */
public class MemoryRuntimeValues extends ValuesCollector
{

	/**
	 * @param handler
	 * @param series
	 */
	public MemoryRuntimeValues( Handler handler, ChartSeries series )
	{
		super( handler, series );
	}

	/*
	 * (non-Javadoc)
	 * @see com.artfulbits.system.graph.ValuesCollector#getRuntimeValue()
	 */
	@Override
	protected double getRuntimeValue()
	{
		final Runtime runtime = Runtime.getRuntime();
		final long usedMemory = runtime.totalMemory() - runtime.freeMemory();

		return percent( 0, runtime.totalMemory(), usedMemory );
	}

	/**
	 * Calculate percent proportion.
	 * 
	 * @param min
	 *          Minimal value that represents 0 (zero) percents.
	 * @param max
	 *          Maximum value that represents 100 percents.
	 * @param value
	 *          Current value which between MIN and MAX.
	 * @return Percent representation of current value.
	 */
	private static final double percent( long min, long max, long value )
	{
		final double dMax = max - min;
		final double dValue = value - min;

		return ( double )( dValue * 100 / dMax );
	}

}
