// #region Copyright
// Copyright ArtfulBits Inc. 2005 - 2010. All rights reserved.
// 
// Use of this code is subject to the terms of our license.
// A copy of the current license can be obtained at any time by e-mailing
// info@artfulbits.com. Re-distribution in any form is strictly
// prohibited. Any infringement will be prosecuted under applicable laws.
// #endregion
package com.artfulbits.aiCharts.Utilities;

import java.text.MessageFormat;

import com.artfulbits.aiCharts.Base.ChartAxis;
import com.artfulbits.aiCharts.Base.ChartAxis.LabelPosition;

/**
 * Helper class that simplify Axis configuration for most common cases.
 * 
 * @author Oleksandr Kucherenko
 */
public final class AxisFormattingHelper
{
	/**
	 * Adjust axis settings for proper displaying percents values.
	 * 
	 * @param axis
	 *          Reference on axis which settings we adjusting.
	 */
	public static final void percentsAxis( final ChartAxis axis )
	{
		axis.setFormat( new MessageFormat("{0}%") ); // remove digits after dot
		axis.getScale().setMinimum( 0d );
		axis.getScale().setMaximum( 100d );
	}

	/**
	 * Adjust axis settings for proper displaying percents values.
	 * 
	 * @param axis
	 *          Reference on axis which settings we adjusting.
	 * @param digits
	 *          quantity of digits which we want to display after dot. Should be
	 *          greater or equal ZERO.
	 */
	public static final void percentsAxis( final ChartAxis axis, int digits )
	    throws IllegalArgumentException
	{
		if( digits < 0 )
			throw new IllegalArgumentException( "Digits quanity can not be less zero." );

		axis.setFormat( new MessageFormat("{0}%") );
		axis.getScale().setMinimum( 0d );
		axis.getScale().setMaximum( 100d );
	}

	/**
	 * Compact space required for axis showing by placing axis labels inside
	 * instead of default outside.
	 * 
	 * @param axis
	 *          reference on axis which view we want to compact.
	 */
	public static final void CompactAxis( final ChartAxis axis )
	{
		axis.setLabelPosition( LabelPosition.Inside );
	}
}
