// #region Copyright
// Copyright ArtfulBits Inc. 2005 - 2010. All rights reserved.
// 
// Use of this code is subject to the terms of our license.
// A copy of the current license can be obtained at any time by e-mailing
// info@artfulbits.com. Re-distribution in any form is strictly
// prohibited. Any infringement will be prosecuted under applicable laws.
// #endregion
package com.artfulbits.aiCharts.MultipleAreas;

import com.artfulbits.aiCharts.ChartView;
import com.artfulbits.aiCharts.Base.ChartArea;
import com.artfulbits.aiCharts.Base.ChartAxis;
import com.artfulbits.aiCharts.Base.ChartSeries;
import com.artfulbits.aiCharts.Types.ChartTypes;

import android.app.Activity;
import android.app.AlertDialog;
import android.app.Dialog;
import android.app.AlertDialog.Builder;
import android.os.Bundle;
import android.view.Menu;
import android.view.MenuItem;

public class MainActivity extends Activity
{
	private final static int AUTO_ALIGN_ITEM_ID = 1;
	private final static int ABOUT_ITEM_ID = 2;
	
	ChartView chartView;

	/** Called when the activity is first created. */
	@Override
	public void onCreate(Bundle savedInstanceState)
	{
		super.onCreate(savedInstanceState);

		chartView = new ChartView(this);
		ChartSeries series1 = new ChartSeries("s1", ChartTypes.Area);
		ChartSeries series2 = new ChartSeries("s2", ChartTypes.Area);
		ChartSeries series3 = new ChartSeries("s3", ChartTypes.Area);
		
		ChartArea area1 = new ChartArea("area1");
		ChartArea area2 = new ChartArea("area2");
		ChartArea area3 = new ChartArea("area3");

		for (int i = 0; i < 20; i++)
		{
			series1.getPoints().addXY(i, 1000 * Math.random());
			series2.getPoints().addXY(i, 100 * Math.random());
			series3.getPoints().addXY(i, 10 * Math.random());
		}

		series1.setArea("area1");
		series2.setArea("area2");
		series3.setArea("area3");

		chartView.getAreas().add(area1);
		chartView.getAreas().add(area2);
		chartView.getAreas().add(area3);
		
		chartView.getSeries().add(series1);
		chartView.getSeries().add(series2);
		chartView.getSeries().add(series3);
		
		setContentView(chartView);
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see android.app.Activity#onCreateOptionsMenu(android.view.Menu)
	 */
	@Override
	public boolean onCreateOptionsMenu(Menu menu)
	{
		menu.add(0, AUTO_ALIGN_ITEM_ID, 0, getString(R.string.autoalign_menu_item_title));
		menu.add(0, ABOUT_ITEM_ID, 0, getString(R.string.about_menu_item_title));
		
		return super.onCreateOptionsMenu(menu);
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see android.app.Activity#onOptionsItemSelected(android.view.MenuItem)
	 */
	@Override
	public boolean onOptionsItemSelected(MenuItem item)
	{
		switch(item.getItemId())
		{
			case ABOUT_ITEM_ID:
			showDialog(ABOUT_ITEM_ID);
			return true;

			case AUTO_ALIGN_ITEM_ID:
				chartView.getChart().setAutoAlignAreas(!chartView.getChart().getAutoAlignAreas());
				return true;				
		}

		return super.onOptionsItemSelected(item);
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see android.app.Activity#onCreateDialog(int)
	 */
	@Override
	protected Dialog onCreateDialog(int id)
	{
		Dialog result = null;
		Builder builder;

		switch (id)
		{
			case ABOUT_ITEM_ID:
				builder = new AlertDialog.Builder(this);

				builder.setTitle(R.string.about_menu_item_title);
				builder.setMessage(R.string.dlg_about_msg);

				builder.setPositiveButton(R.string.dlg_ok_btn_title, null);

				result = builder.create();
			break;

			default:
				result = super.onCreateDialog(id);
			break;
		}

		return result;
	}
}
