// #region Copyright
// Copyright ArtfulBits Inc. 2005 - 2010. All rights reserved.
// 
// Use of this code is subject to the terms of our license.
// A copy of the current license can be obtained at any time by e-mailing
// info@artfulbits.com. Re-distribution in any form is strictly
// prohibited. Any infringement will be prosecuted under applicable laws.
// #endregion
package com.artfulbits.aiCharts.SampleBrowser.Activities;

import java.io.File;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;

import javax.xml.parsers.DocumentBuilder;
import javax.xml.parsers.DocumentBuilderFactory;
import javax.xml.parsers.ParserConfigurationException;

import org.w3c.dom.Document;
import org.w3c.dom.Element;
import org.xml.sax.SAXException;

import android.content.Context;
import android.content.res.Resources;
import android.database.sqlite.SQLiteDatabase;
import android.graphics.Color;
import android.graphics.drawable.Drawable;
import android.text.TextPaint;

import com.artfulbits.aiCharts.ChartView;
import com.artfulbits.aiCharts.Base.ChartArea;
import com.artfulbits.aiCharts.Base.ChartAxis;
import com.artfulbits.aiCharts.Base.ChartAxisStripLine;
import com.artfulbits.aiCharts.Base.ChartLegend;
import com.artfulbits.aiCharts.Base.ChartNamedCollection;
import com.artfulbits.aiCharts.Base.ChartPoint;
import com.artfulbits.aiCharts.Base.ChartPointCollection;
import com.artfulbits.aiCharts.Base.ChartSeries;
import com.artfulbits.aiCharts.Base.ChartLayoutElement.Dock;
import com.artfulbits.aiCharts.SampleBrowser.R;
import com.artfulbits.aiCharts.Types.ChartTypes;

public class ChartSettingsHelper
{
  // #region Members
  private Resources m_resources;
  
  private static SQLiteDatabase m_database;
  
  private static final String DATABASE_TABLENAME = "ChartData";
  
  private static final String c_databaseName = "data.db";
  
  private static final String c_databasePath = "/data/data/com.artfulbits.aiCharts.SampleBrowser/databases/";
  
  private static final ChartPoint[][] m_pointsCache = new ChartPoint[][]
  {
      new ChartPoint[]
      { new ChartPoint( 0, 10 ), new ChartPoint( 2, 15 ),
          new ChartPoint( 5, 25 ), new ChartPoint( 7, 35 ),
          new ChartPoint( 10, 15 ), new ChartPoint( 13, 10 ),
          new ChartPoint( 15, 12 ), new ChartPoint( 17, 25 ),
          new ChartPoint( 20, 4 ) },
      new ChartPoint[]
      { new ChartPoint( 0, 20 ), new ChartPoint( 2, 30 ),
          new ChartPoint( 5, 40 ), new ChartPoint( 7, 22 ),
          new ChartPoint( 10, 18 ), new ChartPoint( 13, 5 ),
          new ChartPoint( 15, 15 ), new ChartPoint( 17, 15 ),
          new ChartPoint( 20, 5 ) },
      new ChartPoint[]
      { new ChartPoint( 0, 15 ), new ChartPoint( 2, 25 ),
          new ChartPoint( 5, 30 ), new ChartPoint( 7, 20 ),
          new ChartPoint( 10, 15 ), new ChartPoint( 13, 18 ),
          new ChartPoint( 15, 20 ), new ChartPoint( 17, 19 ),
          new ChartPoint( 20, 10 ) } };
  
  // #endregion
  
  // #region Nested types
  public enum DataSourceType
  {
    RandomPoints, XML, SQLite
  }
  // #endregion
  
  // #region Public methods
  public ChartSettingsHelper( Context context )
  {
    m_resources = context.getResources();
  }
  
  public void setSeriesAppearence(
      ChartNamedCollection<ChartSeries> seriesCollection )
  {
    Drawable[] availableDrawables = new Drawable[]
    { m_resources.getDrawable( R.drawable.gradient_blue ),
        m_resources.getDrawable( R.drawable.gradient_orange ),
        m_resources.getDrawable( R.drawable.gradient_red ) };
    
    int collectionSize = seriesCollection.size();
    Drawable cachedDrawable;
    for( int i = 0; i < collectionSize; i++ )
    {
      cachedDrawable = availableDrawables[ i % availableDrawables.length ];
      cachedDrawable.setAlpha( 225 );
      
      seriesCollection.get( i ).setLineWidth( 3 );
      
      if(seriesCollection.get(i).getType() == ChartTypes.Pie)
      {
      	seriesCollection.get( i ).setBackDrawable( null );
      }
      else
      {
      	seriesCollection.get( i ).setBackDrawable( cachedDrawable );
      }
    }
  }
  
  public void setAxesAppearence( ChartArea area )
  {
    TextPaint axisLabelsPaint = new TextPaint();
    axisLabelsPaint.setColor( Color.BLACK );
    axisLabelsPaint.setDither( true );
    axisLabelsPaint.setAntiAlias( true );
    
    for( ChartAxis axis : area.getAxes() )
    {
      axis.setLineType( 2, Color.BLACK );
      axis.setSpacing( 5 );
      axis.setLineType( 2, Color.BLACK );
      axis.getLabelPaint().set( axisLabelsPaint );
    }
    
    ChartAxis horizontalAxis = area.getDefaultXAxis();
    horizontalAxis.getScale().setRange( 0, 20 );
    ChartAxisStripLine stripline = new ChartAxisStripLine( 2, 4 );
    stripline.setColor( 0xFFC1CEE3 );
    stripline.setStart( -1 );
    horizontalAxis.getStripLines().add( stripline );
  }
  
  public void FillSereisPoints( ChartSeries series, int seriesIndex,
      DataSourceType sourceType )
  {
    ChartPointCollection seriesPoints = series.getPoints();
    if( sourceType == DataSourceType.RandomPoints )
    {
      ChartPoint[] pointsArray = m_pointsCache[ seriesIndex
          % m_pointsCache.length ];
      for( int i = 0; i < pointsArray.length; i++ )
      {
        seriesPoints.add( pointsArray[ i ] );
      }
      return;
    }
    if( sourceType == DataSourceType.XML )
    {
      seriesPoints.setData( getXmlElement(seriesIndex), true, "X", "Y" );
      return;
    }
    if( sourceType == DataSourceType.SQLite )
    {
      seriesPoints.setData( getDatabase(), DATABASE_TABLENAME, new String[]
      { "Data" + (seriesIndex % 3 + 1) } );
      return;
    }
  }
  
  public void addLegend(ChartView chartView)
  {
    ChartLegend legend = new ChartLegend();
    legend.setDock( Dock.Right );
    legend.getTextPaint().setAntiAlias( true );
    legend.getTextPaint().setColor( Color.BLACK );
    chartView.getLegends().add(legend);
  }
  // #endregion
  
  // #region Implementation
  
  // #endregion
  
  private Element getXmlElement( int seriesIndex )
  {
    DocumentBuilderFactory dbf = DocumentBuilderFactory.newInstance();
    Document dom1 = null;
    try {

      //Using factory get an instance of document builder
      DocumentBuilder db = dbf.newDocumentBuilder();

      //parse using builder to get DOM representation of the XML file from assests.
      dom1 = db.parse(m_resources.getAssets().open( "series" + (seriesIndex%3+1)+"Points.xml" ));
      
    }catch(ParserConfigurationException pce) {
      pce.printStackTrace();
    }catch(SAXException se) {
      se.printStackTrace();
    }catch(IOException ioe) {
      ioe.printStackTrace();
    }
    return dom1.getDocumentElement();
  }
  
  private SQLiteDatabase getDatabase()
  {
    if( m_database == null )
    {
      String databaseFilePath = c_databasePath + c_databaseName;
      
      // Making necessary paths.
      new File( c_databasePath ).mkdirs();
      // Resorting to existing database instead of writing a new one.
      if( new File( databaseFilePath ).exists() )
      {
        m_database = SQLiteDatabase.openDatabase( databaseFilePath, null,
            SQLiteDatabase.OPEN_READONLY );
        return m_database;
      }
      
      try
      {
        InputStream in = m_resources.getAssets().open( c_databaseName );
        
        OutputStream out;
        out = new FileOutputStream( databaseFilePath );
        
        byte[] buf = new byte[ 1024 ];
        int len;
        while( ( len = in.read( buf ) ) > 0 )
        {
          out.write( buf, 0, len );
        }
        
        out.close();
        in.close();
      }
      catch( IOException e )
      {
        e.printStackTrace();
      }
      
      m_database = SQLiteDatabase.openDatabase( databaseFilePath, null,
          SQLiteDatabase.OPEN_READONLY );
    }
    
    return m_database;
  }
}
