// #region Copyright
// Copyright ArtfulBits Inc. 2005 - 2010. All rights reserved.
// 
// Use of this code is subject to the terms of our license.
// A copy of the current license can be obtained at any time by e-mailing
// info@artfulbits.com. Re-distribution in any form is strictly
// prohibited. Any infringement will be prosecuted under applicable laws.
// #endregion
package com.artfulbits.aiCharts.SampleBrowser.Activities;

import android.app.Activity;
import android.app.AlertDialog;
import android.app.Dialog;
import android.app.AlertDialog.Builder;
import android.os.Bundle;
import android.view.Menu;
import android.view.MenuItem;

import com.artfulbits.aiCharts.ChartView;
import com.artfulbits.aiCharts.Base.ChartArea;
import com.artfulbits.aiCharts.Base.ChartSeries;
import com.artfulbits.aiCharts.SampleBrowser.R;
import com.artfulbits.aiCharts.Types.ChartTypes;

public class SplineActivity extends Activity
{
	private final static int ABOUT_ITEM_ID = 1;
	
	@Override
	protected void onCreate(Bundle savedInstanceState)
	{
		super.onCreate(savedInstanceState);
		
		ChartView chartView = new ChartView(this);
		ChartArea area = new ChartArea();
		ChartSeries series1 = new ChartSeries("series1", ChartTypes.Spline);
		ChartSeries series2 = new ChartSeries("series2", ChartTypes.Spline);
		ChartSeries series3 = new ChartSeries("series3", ChartTypes.Spline);
		
		chartView.getSeries().add(series1);
		chartView.getSeries().add(series2);
		chartView.getSeries().add(series3);
		
		chartView.getAreas().add(area);
		
		this.setContentView(chartView);
		
		chartView.setBackgroundResource(R.drawable.background);
		ChartSettingsHelper settingsHelper = new ChartSettingsHelper(this);
		
		ChartSettingsHelper.DataSourceType sourceType = (ChartSettingsHelper.DataSourceType)getIntent()
				.getExtras().get("DATA_SOURCE_TYPE");
		for(int i = 0; i < chartView.getSeries().size(); i++)
		{
			settingsHelper.FillSereisPoints(chartView.getSeries().get(i), i,
					sourceType);
		}
		
		if(getIntent().getBooleanExtra("LEGEND_VISIBILITY", false))
		{
			settingsHelper.addLegend(chartView);
		}
		settingsHelper.setSeriesAppearence(chartView.getSeries());
		settingsHelper.setAxesAppearence(area);
		
	}
	
	@Override
	public boolean onCreateOptionsMenu(Menu menu)
	{
		menu.add(0, ABOUT_ITEM_ID, 0, getString(R.string.about_menu_item_title));
		return super.onCreateOptionsMenu(menu);
	}
	
	@Override
	protected Dialog onCreateDialog(int id)
	{
		Dialog result = null;
		Builder builder;
		
		switch(id)
		{
			case ABOUT_ITEM_ID:
				builder = new AlertDialog.Builder(this);
				
				builder.setTitle(R.string.about_menu_item_title);
				builder.setMessage(R.string.dlg_about_msg);
				
				builder.setPositiveButton(R.string.dlg_ok_btn_title, null);
				
				result = builder.create();
				break;
			
			default:
				result = super.onCreateDialog(id);
				break;
		}
		
		return result;
	}
	
	@Override
	public boolean onMenuItemSelected(int featureId, MenuItem item)
	{
		switch(item.getItemId())
		{
			case ABOUT_ITEM_ID:
				showDialog(ABOUT_ITEM_ID);
				return true;
				
			default:
				return false;
		}
	}
}
