// #region Copyright
// Copyright ArtfulBits Inc. 2005 - 2010. All rights reserved.
// 
// Use of this code is subject to the terms of our license.
// A copy of the current license can be obtained at any time by e-mailing
// info@artfulbits.com. Re-distribution in any form is strictly
// prohibited. Any infringement will be prosecuted under applicable laws.
// #endregion
package com.artfulbits.aiCharts.SampleBrowser;

import java.util.ArrayList;
import java.util.List;

import com.artfulbits.aiCharts.SampleBrowser.Activities.ChartSettingsHelper;

import android.app.Activity;
import android.app.AlertDialog;
import android.app.Dialog;
import android.app.AlertDialog.Builder;
import android.content.Context;
import android.content.Intent;
import android.content.pm.ActivityInfo;
import android.content.pm.PackageManager;
import android.content.pm.ResolveInfo;
import android.content.res.Resources;
import android.graphics.Color;
import android.os.Bundle;
import android.view.Gravity;
import android.view.Menu;
import android.view.MenuItem;
import android.view.SubMenu;
import android.view.View;
import android.view.ViewGroup;
import android.view.Window;
import android.view.MenuItem.OnMenuItemClickListener;
import android.view.animation.Transformation;
import android.widget.AdapterView;
import android.widget.BaseAdapter;
import android.widget.Gallery;
import android.widget.ImageView;
import android.widget.LinearLayout;
import android.widget.TextView;
import android.widget.AdapterView.OnItemClickListener;
import android.widget.ImageView.ScaleType;

public class SampleBrowserActivity extends Activity
{
	private final static int ABOUT_ITEM_ID = 3;
	
	// #region Nested types
	class GalleryEx extends Gallery
	{
		public GalleryEx(Context context)
		{
			super(context);
		}
		
		@Override
		protected boolean getChildStaticTransformation(View child, Transformation t)
		{
			int index = indexOfChild(child);
			int selected = indexOfChild(getSelectedView());
			float aScale = Math.max(0.99f - 0.4f * Math.abs(selected - index), 0.1f);
			float mScale = Math.max(1.2f - 0.3f * Math.abs(selected - index), 0.1f);
			
			int cX = (child.getRight() - child.getLeft()) / 2;
			int cY = (child.getBottom() - child.getTop()) / 2;
			
			t.clear();
			t.setAlpha(aScale);
			t.getMatrix().setScale(mScale, mScale, cX, cY);
			t.setTransformationType(Transformation.TYPE_BOTH);
			
			return true;
		}
	}
	
	class ActivitiesAdapter extends BaseAdapter
	{
		
		public final ArrayList<ActivityInfo> Activities = new ArrayList<ActivityInfo>();
		
		@Override
		public int getCount()
		{
			return Activities.size();
		}
		
		@Override
		public Object getItem(int position)
		{
			return Activities.get(position);
		}
		
		@Override
		public long getItemId(int position)
		{
			return position;
		}
		
		@Override
		public View getView(int position, View convertView, ViewGroup parent)
		{
			if(convertView == null)
			{
				LinearLayout layout = new LinearLayout(SampleBrowserActivity.this);
				ImageView image = new ImageView(SampleBrowserActivity.this);
				TextView label = new TextView(SampleBrowserActivity.this);
				ActivityInfo info = Activities.get(position);
				
				image.setImageResource(info.getIconResource());
				image.setScaleType(ScaleType.FIT_XY);
				
				label.setText(info.loadLabel(getPackageManager()));
				label.setGravity(Gravity.CENTER_HORIZONTAL);
				label.setTextColor(Color.WHITE);
				
				layout.setOrientation(LinearLayout.VERTICAL);
				layout.addView(image, new LinearLayout.LayoutParams(150, 150));
				layout.addView(label);
				layout.setTag(info);
				
				return layout;
			}
			
			return convertView;
		}
		
	}
	
	// #endregion
	
	// #region Members
	private boolean m_legendVisible;
	
	private ChartSettingsHelper.DataSourceType m_dataSourceType = ChartSettingsHelper.DataSourceType.RandomPoints;
	
	// #endregion
	
	@Override
	public void onCreate(Bundle savedInstanceState)
	{
		super.onCreate(savedInstanceState);
		
		requestWindowFeature(Window.FEATURE_NO_TITLE);
		
		Gallery gallery = new GalleryEx(this);
		
		PackageManager packageManager = getPackageManager();
		Intent queryIntent = new Intent(Intent.ACTION_MAIN, null);
		
		queryIntent.addCategory("CHART_SAMPLE");
		
		List<ResolveInfo> result = packageManager.queryIntentActivities(
				queryIntent, 0);
		ActivitiesAdapter activitiesAdapter = new ActivitiesAdapter();
		
		for(int i = 0; i < result.size(); i++)
		{
			ResolveInfo resolveInfo = result.get(i);
			
			activitiesAdapter.Activities.add(resolveInfo.activityInfo);
		}
		
		gallery.setAdapter(activitiesAdapter);
		gallery.setOnItemClickListener(new OnItemClickListener()
		{
			@Override
			public void onItemClick(AdapterView<?> arg0, View arg1, int arg2,
					long arg3)
			{
				ActivityInfo info = (ActivityInfo)arg1.getTag();
				Intent intent = new Intent();
				intent.setClassName(info.packageName, info.name);
				intent.putExtra("LEGEND_VISIBILITY", m_legendVisible);
				intent.putExtra("DATA_SOURCE_TYPE", m_dataSourceType);
				startActivity(intent);
			}
		});
		
		this.setContentView(gallery);
	}
	
	/*
	 * (non-Javadoc)
	 * 
	 * @see android.app.Activity#onCreateDialog(int)
	 */
	@Override
	protected Dialog onCreateDialog(int id)
	{
		Dialog result = null;
		Builder builder;
		
		switch(id)
		{
			case ABOUT_ITEM_ID:
				builder = new AlertDialog.Builder(this);
				
				builder.setTitle(R.string.about_menu_item_title);
				builder.setMessage(R.string.dlg_about_msg);
				
				builder.setPositiveButton(R.string.dlg_ok_btn_title, null);
				
				result = builder.create();
				break;
			
			default:
				result = super.onCreateDialog(id);
				break;
		}
		
		return result;
	}
	
	/*
	 * (non-Javadoc)
	 * 
	 * @see android.app.Activity#onCreateOptionsMenu(android.view.Menu)
	 */
	@Override
	public boolean onCreateOptionsMenu(Menu menu)
	{
		MenuItem i = menu.add(0, 0, 0, null);
		i.setOnMenuItemClickListener(new OnMenuItemClickListener()
		{
			public boolean onMenuItemClick(MenuItem arg0)
			{
				m_legendVisible = !m_legendVisible;
				return true;
			}
		});
		SubMenu sm = menu.addSubMenu(getResources().getString(
				R.string.datasource_option_title));
		MenuItem pointsArrayMenuItem = sm.add(R.string.points_array_option_title);
		pointsArrayMenuItem
				.setOnMenuItemClickListener(new OnMenuItemClickListener()
				{
					public boolean onMenuItemClick(MenuItem menu)
					{
						m_dataSourceType = ChartSettingsHelper.DataSourceType.RandomPoints;
						return true;
					}
				});
		
		MenuItem xmlSourceMenuItem = sm.add(R.string.xml_option_title);
		xmlSourceMenuItem.setOnMenuItemClickListener(new OnMenuItemClickListener()
		{
			public boolean onMenuItemClick(MenuItem menu)
			{
				m_dataSourceType = ChartSettingsHelper.DataSourceType.XML;
				return true;
			}
		});
		
		MenuItem sqliteMenuItem = sm.add(R.string.sqlite_option_title);
		sqliteMenuItem.setOnMenuItemClickListener(new OnMenuItemClickListener()
		{
			public boolean onMenuItemClick(MenuItem menu)
			{
				m_dataSourceType = ChartSettingsHelper.DataSourceType.SQLite;
				return true;
			}
		});
		menu.add(0, ABOUT_ITEM_ID, 0, getString(R.string.about_menu_item_title));
		return super.onCreateOptionsMenu(menu);
	}
	
	/*
	 * (non-Javadoc)
	 * 
	 * @see android.app.Activity#onPrepareOptionsMenu(android.view.Menu)
	 */
	@Override
	public boolean onPrepareOptionsMenu(Menu menu)
	{
		MenuItem legendItem = menu.findItem(0);
		Resources r = getResources();
		legendItem.setTitle(m_legendVisible ? r
				.getString(R.string.legend_off_option_title) : r
				.getString(R.string.legend_on_option_title));
		return super.onPrepareOptionsMenu(menu);
	}
	
	/*
	 * (non-Javadoc)
	 * 
	 * @see android.app.Activity#onOptionsItemSelected(android.view.MenuItem)
	 */
	@Override
	public boolean onOptionsItemSelected(MenuItem item)
	{
		if(item.getItemId() == ABOUT_ITEM_ID)
		{
			showDialog(ABOUT_ITEM_ID);
			return true;
		}
		return super.onOptionsItemSelected(item);
	}
}
