// #region Copyright
// Copyright ArtfulBits Inc. 2005 - 2010. All rights reserved.
// 
// Use of this code is subject to the terms of our license.
// A copy of the current license can be obtained at any time by e-mailing
// info@artfulbits.com. Re-distribution in any form is strictly
// prohibited. Any infringement will be prosecuted under applicable laws.
// #endregion
package com.artfulbits.aiCharts.StepAreaSample;

import com.artfulbits.aiCharts.ChartView;
import com.artfulbits.aiCharts.Base.ChartArea;
import com.artfulbits.aiCharts.Base.ChartSeries;
import com.artfulbits.aiCharts.Base.ChartTransform;

import android.graphics.Canvas;
import android.graphics.ColorFilter;
import android.graphics.Paint;
import android.graphics.PointF;
import android.graphics.Rect;
import android.graphics.drawable.Drawable;

public class TwoColorDrawable extends Drawable
{
	private final Paint m_paint = new Paint(); 
	private final ChartArea m_area;
	private final int m_color1;
	private final int m_color2;
	private final double m_value;
	
	public TwoColorDrawable(ChartArea area, int color1, int color2, double value)
	{
		m_area = area;
		m_color1 = color1;
		m_color2 = color2;
		m_value = value;
	}

	@Override
	public void draw(Canvas arg0)
	{
		final Rect bounds = getBounds();
		final ChartTransform transform = ChartTransform.create(m_area);
		final PointF outPoint = new PointF(); 
		
		transform.getPoint(0, m_value, outPoint);

		if(outPoint.y < bounds.bottom)
		{
			float value = Math.max(outPoint.y, bounds.top); 
			
			m_paint.setColor(m_color1);
			arg0.drawRect(bounds.left, value, bounds.right, bounds.bottom, m_paint);
		}

		if(outPoint.y > bounds.top)
		{
			float value = Math.min(outPoint.y, bounds.bottom); 
			
			m_paint.setColor(m_color2);
			arg0.drawRect(bounds.left, bounds.top, bounds.right, value, m_paint);
		}
	}

	@Override
	public int getOpacity()
	{
		return m_paint.getAlpha();
	}

	@Override
	public void setAlpha(int arg0)
	{
		m_paint.setAlpha(arg0);
	}

	@Override
	public void setColorFilter(ColorFilter arg0)
	{
		m_paint.setColorFilter(arg0);
	}	
}
