// #region Copyright
// Copyright ArtfulBits Inc. 2005 - 2010. All rights reserved.
// 
// Use of this code is subject to the terms of our license.
// A copy of the current license can be obtained at any time by e-mailing
// info@artfulbits.com. Re-distribution in any form is strictly
// prohibited. Any infringement will be prosecuted under applicable laws.
// #endregion
package aiCharts.HitTestSample;

import java.util.List;

import com.artfulbits.aiCharts.ChartView;
import com.artfulbits.aiCharts.Base.ChartArea;
import com.artfulbits.aiCharts.Base.ChartPoint;
import com.artfulbits.aiCharts.Base.ChartSeries;
import com.artfulbits.aiCharts.Base.ChartTitle;
import com.artfulbits.aiCharts.Types.ChartPieType;
import com.artfulbits.aiCharts.Types.ChartTypes;

import android.app.Activity;
import android.app.AlertDialog;
import android.app.Dialog;
import android.app.AlertDialog.Builder;
import android.graphics.Point;
import android.os.Bundle;
import android.view.Menu;
import android.view.MenuItem;
import android.view.MotionEvent;
import android.view.View;
import android.view.View.OnTouchListener;

public class HitTestActivity extends Activity
{
	private final static int ABOUT_ITEM_ID = 1;
	
	Point m_tPoint = new Point();
	
	ChartPoint m_point = null;
	
	int m_startOffset = 0;
	
	/** Called when the activity is first created. */
	@Override
	public void onCreate(Bundle savedInstanceState)
	{
		super.onCreate(savedInstanceState);
		
		ChartView chartView = new ChartView(this);
		ChartSeries series1 = new ChartSeries("Pie", ChartTypes.Pie);
		
		for(int i = 0; i < 10; i++)
		{
			series1.getPoints().addXY(i, Math.random());
		}
		
		chartView.setHitTestEnabled(true);
		chartView.getTitles().add(new ChartTitle(getString(R.string.chart_title)));
		chartView.getSeries().add(series1);
		chartView.getAreas().add(new ChartArea());
		chartView.setOnTouchListener(new OnTouchListener()
		{
			@Override
			public boolean onTouch(View v, MotionEvent event)
			{
				ChartView chartView = (ChartView)v;
				int x = (int)event.getX() - chartView.getLeft();
				int y = (int)event.getY() - chartView.getTop();
				
				if(event.getAction() == MotionEvent.ACTION_DOWN)
				{
					m_tPoint.x = x;
					m_tPoint.y = y;
					
					List<Object> res = chartView.getChart().hitTest(m_tPoint.x,
							m_tPoint.y);
					
					for (Object object : res)
					{
						if(object instanceof ChartPoint)
						{
							m_point = (ChartPoint)object;
							m_startOffset = m_point.getAttribute(ChartPieType.EXPAND_RADIUS);
							
							return true;
						}
					}
				}
				else if(event.getAction() == MotionEvent.ACTION_UP)
				{
					m_point = null;
				}
				else if(event.getAction() == MotionEvent.ACTION_MOVE && m_point != null)
				{
					int dx1 = m_tPoint.x - chartView.getWidth() / 2;
					int dx2 = x - chartView.getWidth() / 2;
					int dy1 = m_tPoint.y - chartView.getHeight() / 2;
					int dy2 = y - chartView.getHeight() / 2;
					
					int l1 = (int)Math.sqrt(dx1 * dx1 + dy1 * dy1);
					int l2 = (int)Math.sqrt(dx2 * dx2 + dy2 * dy2);
					
					m_point.setAttribute(ChartPieType.EXPAND_RADIUS, Math.min(
							m_startOffset + (l2 - l1), 30));
				}
				
				return true;
			}
		});
		
		setContentView(chartView);
	}
	
	@Override
	public boolean onCreateOptionsMenu(Menu menu)
	{
		menu.add(0, ABOUT_ITEM_ID, 0, getString(R.string.about_menu_item_title));
		return super.onCreateOptionsMenu(menu);
	}
	
	/*
	 * (non-Javadoc)
	 * 
	 * @see android.app.Activity#onOptionsItemSelected(android.view.MenuItem)
	 */
	@Override
	public boolean onOptionsItemSelected(MenuItem item)
	{
		if(item.getItemId() == ABOUT_ITEM_ID)
		{
			showDialog(ABOUT_ITEM_ID);
			return true;
		}
		return super.onOptionsItemSelected(item);
	}
	
	/*
	 * (non-Javadoc)
	 * 
	 * @see android.app.Activity#onCreateDialog(int)
	 */
	@Override
	protected Dialog onCreateDialog(int id)
	{
		Dialog result = null;
		Builder builder;
		
		switch(id)
		{
			case ABOUT_ITEM_ID:
				builder = new AlertDialog.Builder(this);
				
				builder.setTitle(R.string.about_menu_item_title);
				builder.setMessage(R.string.dlg_about_msg);
				
				builder.setPositiveButton(R.string.dlg_ok_btn_title, null);
				
				result = builder.create();
				break;
			
			default:
				result = super.onCreateDialog(id);
				break;
		}
		
		return result;
	}
}
