// #region Copyright
// Copyright ArtfulBits Inc. 2005 - 2010. All rights reserved.
// 
// Use of this code is subject to the terms of our license.
// A copy of the current license can be obtained at any time by e-mailing
// info@artfulbits.com. Re-distribution in any form is strictly
// prohibited. Any infringement will be prosecuted under applicable laws.
// #endregion
package com.artfulbits.aiCharts.samples.linehittest;

import java.util.List;

import android.app.Activity;
import android.app.AlertDialog;
import android.app.Dialog;
import android.app.AlertDialog.Builder;
import android.graphics.RectF;
import android.os.Bundle;
import android.view.Menu;
import android.view.MenuItem;
import android.view.MotionEvent;
import android.view.View;
import android.view.View.OnTouchListener;

import com.artfulbits.aiCharts.ChartView;
import com.artfulbits.aiCharts.Base.ChartArea;
import com.artfulbits.aiCharts.Base.ChartAxis;
import com.artfulbits.aiCharts.Base.ChartPoint;
import com.artfulbits.aiCharts.Base.ChartSeries;

public class MainActivity extends Activity
{
	private final static int ABOUT_ITEM_ID = 1;
	private ChartView m_chartView;
	private ChartPoint m_dragPoint = null;
	private final OnTouchListener m_pointDragListener = new OnTouchListener()
	{
		@Override
		public boolean onTouch(View v, MotionEvent event)
		{
			int x = (int) event.getX();
			int y = (int) event.getY();

			switch (event.getAction())
			{
				case MotionEvent.ACTION_DOWN:
				{
					List<Object> hitObjects = m_chartView.hitTest(x, y);
					
					for (Object object : hitObjects) 
					{
						if(object instanceof ChartPoint) 
							// hitObjects may contain any elements : legend, 
							// title, axis, points...
						{
							m_dragPoint = (ChartPoint)object;
							break;
						}
					}
				}
				break;
				
				case MotionEvent.ACTION_MOVE:
				if(m_dragPoint != null)
				{
					m_dragPoint.setY(getYValueByTouch(y));
				}
				break;
				
				case MotionEvent.ACTION_UP:
				{
					m_dragPoint = null;
				}
				break;
			}
			
			return true;
		}
	};

	/** Called when the activity is first created. */
	@Override
	public void onCreate(Bundle savedInstanceState)
	{
		super.onCreate(savedInstanceState);
		setContentView(R.layout.main);

		m_chartView = (ChartView) findViewById(R.id.chart);
		
		m_chartView.setHitTestEnabled(true); // enable hit testing for series
		m_chartView.setOnTouchListener(m_pointDragListener); // set touch listener

		for (int j = 0; j < m_chartView.getSeries().size(); j++)
		{
			ChartSeries series = m_chartView.getSeries().get(j);
			
			for (int i = 0; i < 6; i++)
			{
				series.getPoints().addXY(i, 200 * Math.random() - 100);
			}
		}
	}

	private double getYValueByTouch(float y)
	{
		ChartArea area = m_chartView.getAreas().get(0);
		ChartAxis axis = area.getDefaultYAxis();
		RectF axisBounds = axis.getBounds(); 
		
		double toAxis = (axisBounds.bottom - y) / axisBounds.height();
		
		return axis.getScale().coefficientToValue(toAxis);
	}
	
	/*
	 * (non-Javadoc)
	 * 
	 * @see android.app.Activity#onCreateOptionsMenu(android.view.Menu)
	 */
	@Override
	public boolean onCreateOptionsMenu(Menu menu)
	{
		menu.add(0, ABOUT_ITEM_ID, 0, getString(R.string.about_menu_item_title));
		return super.onCreateOptionsMenu(menu);
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see android.app.Activity#onOptionsItemSelected(android.view.MenuItem)
	 */
	@Override
	public boolean onOptionsItemSelected(MenuItem item)
	{
		if (item.getItemId() == ABOUT_ITEM_ID)
		{
			showDialog(ABOUT_ITEM_ID);
			return true;
		}
		return super.onOptionsItemSelected(item);
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see android.app.Activity#onCreateDialog(int)
	 */
	@Override
	protected Dialog onCreateDialog(int id)
	{
		Dialog result = null;
		Builder builder;

		switch (id)
		{
			case ABOUT_ITEM_ID:
				builder = new AlertDialog.Builder(this);

				builder.setTitle(R.string.about_menu_item_title);
				builder.setMessage(R.string.dlg_about_msg);

				builder.setPositiveButton(R.string.dlg_ok_btn_title, null);

				result = builder.create();
			break;

			default:
				result = super.onCreateDialog(id);
			break;
		}

		return result;
	}
}
