// #region Copyright
// Copyright ArtfulBits Inc. 2005 - 2010. All rights reserved.
// 
// Use of this code is subject to the terms of our license.
// A copy of the current license can be obtained at any time by e-mailing
// info@artfulbits.com. Re-distribution in any form is strictly
// prohibited. Any infringement will be prosecuted under applicable laws.
// #endregion
package com.artfulbits.aiCharts.ZoomSample;

import java.util.Random;

import com.artfulbits.aiCharts.ChartView;
import com.artfulbits.aiCharts.Base.ChartAxis;
import com.artfulbits.aiCharts.Base.ChartPointCollection;
import com.artfulbits.aiCharts.Base.ChartSeries;

import android.app.Activity;
import android.app.AlertDialog;
import android.app.Dialog;
import android.app.AlertDialog.Builder;
import android.os.Bundle;
import android.view.Menu;
import android.view.MenuItem;
import android.view.View;
import android.view.View.OnClickListener;
import android.widget.ZoomControls;

public class MainActivity extends Activity
{
	private final static int ABOUT_ITEM_ID = 1;
	
	/** Called when the activity is first created. */
	@Override
	public void onCreate(Bundle savedInstanceState)
	{
		super.onCreate(savedInstanceState);

		setContentView(R.layout.main);

		ZoomControls zoomControls = (ZoomControls) findViewById(R.id.zoomControls);
		final ChartView chartView = (ChartView) findViewById(R.id.chart);
		final ChartAxis xAxis = chartView.getAreas().get(0).getDefaultXAxis();

		chartView.setPanning(ChartView.PANNING_HORIZONTAL);

		for (int is = 0; is < chartView.getSeries().size(); is++)
		{
			ChartPointCollection points = chartView.getSeries().get(is).getPoints();
			
			for (int ip = 0; ip < 200; ip++)
			{
				points.addXY(ip, 100 * Math.random());
			}
		}

		zoomControls.setOnZoomInClickListener(new OnClickListener()
		{
			@Override
			public void onClick(View arg0)
			{
				xAxis.getScale().mulZoom(0.5);
			}
		});

		zoomControls.setOnZoomOutClickListener(new OnClickListener()
		{
			@Override
			public void onClick(View arg0)
			{
				xAxis.getScale().mulZoom(2);
			}
		});
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see android.app.Activity#onCreateOptionsMenu(android.view.Menu)
	 */
	@Override
	public boolean onCreateOptionsMenu(Menu menu)
	{
		menu.add(0, ABOUT_ITEM_ID, 0, getString(R.string.about_menu_item_title));
		return super.onCreateOptionsMenu(menu);
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see android.app.Activity#onOptionsItemSelected(android.view.MenuItem)
	 */
	@Override
	public boolean onOptionsItemSelected(MenuItem item)
	{
		if (item.getItemId() == ABOUT_ITEM_ID)
		{
			showDialog(ABOUT_ITEM_ID);
			return true;
		}
		return super.onOptionsItemSelected(item);
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see android.app.Activity#onCreateDialog(int)
	 */
	@Override
	protected Dialog onCreateDialog(int id)
	{
		Dialog result = null;
		Builder builder;

		switch (id)
		{
			case ABOUT_ITEM_ID:
				builder = new AlertDialog.Builder(this);

				builder.setTitle(R.string.about_menu_item_title);
				builder.setMessage(R.string.dlg_about_msg);

				builder.setPositiveButton(R.string.dlg_ok_btn_title, null);

				result = builder.create();
			break;

			default:
				result = super.onCreateDialog(id);
			break;
		}

		return result;
	}
}
