// #region Copyright
// Copyright ArtfulBits Inc. 2005 - 2010. All rights reserved.
// 
// Use of this code is subject to the terms of our license.
// A copy of the current license can be obtained at any time by e-mailing
// info@artfulbits.com. Re-distribution in any form is strictly
// prohibited. Any infringement will be prosecuted under applicable laws.
// #endregion
package aiCharts.Demo.Financial;

import java.util.ArrayList;

import aiCharts.Demo.Financial.UI.OptionsPane;
import aiCharts.Demo.Financial.Utils.ChartPreferencesHandler;
import android.app.Activity;
import android.content.Intent;
import android.content.pm.ActivityInfo;
import android.graphics.Matrix;
import android.graphics.PointF;
import android.os.Bundle;
import android.view.GestureDetector;
import android.view.KeyEvent;
import android.view.MotionEvent;
import android.view.View;
import android.view.ViewGroup;
import android.view.Window;
import android.view.WindowManager;
import android.view.View.OnClickListener;
import android.widget.AdapterView;
import android.widget.ImageView;
import android.widget.LinearLayout;
import android.widget.Toast;
import android.widget.AdapterView.OnItemClickListener;

import com.artfulbits.aiCharts.ChartView;
import com.artfulbits.aiCharts.Base.ChartAxis;
import com.artfulbits.aiCharts.Base.ChartAxisScale;
import com.artfulbits.aiCharts.Base.ChartLegend;
import com.artfulbits.aiCharts.Base.ChartPalette;
import com.artfulbits.aiCharts.Base.MathUtils;
import com.artfulbits.aiCharts.Base.ChartLayoutElement.Alignment;
import com.artfulbits.aiCharts.Base.ChartLayoutElement.Dock;

/**
 * Started by aiChartDemo activity. Used to edit chart's settings.
 * 
 * @author pturchenko
 */
public class ChartEditorActivity extends Activity
{
	// #region Members
	
	// #region Constants
	
	// #region Gesture constants
	// Number of points required to recognize circular.
	private static float RADIUS_TOLERANCE = .35f;
	
	// Minimum possible difference between circular gesture angles.
	private static float ANGLE_DEVIATION = .1f;
	
	// Fling gesture major move.
	private static final int FLING_MAJOR_MOVE = 60;
	
	// Determines portion of the scroll applied to the axis upon zoom gestures.
	private static final double AXIS_SHIFT_PORTION = 0.2;
	
	// Identified for zoom in user gesture.
	private static final int ZOOM_IN_GESTURE = 0;
	
	// Identified for zoom out user gesture.
	private static final int ZOOM_OUT_GESTURE = 1;
	
	// Identified for scroll left user gesture.
	private static final int SCROLL_LEFT_GESTURE = 2;
	
	// Identified for scroll right user gesture.
	private static final int SCROLL_RIGHT_GESTURE = 3;
	
	// Identified for scroll up user gesture.
	private static final int SCROLL_UP_GESTURE = 4;
	
	// Identified for scroll down user gesture.
	private static final int SCROLL_DOWN_GESTURE = 5;
	
	// Axis zoom scale.
	private static final int ZOOM_SCALE = 2;
	
	// #endregion
	
	// #endregion
	
	// #region Private fields
	// Array to store user movements in order to validate them for circular
	// gesture.
	private ArrayList<PointF> m_gesturePoints = new ArrayList<PointF>();
	
	// Identifies that circular gesture recognition was started.
	private boolean m_circularGestureStarted;
	
	// Gesture scanner supplied to activity in order to receive user input
	// actions.
	private Toast m_gestureToast;
	
	private ImageView m_gestureImage;
	
	private ChartPreferencesHandler m_preferencesHandler;
	
	private OptionsPane m_rootOptionsPane;
	
	private OptionsPane m_legendOptionsPane;
	
	private OptionsPane m_paletteOptionsPane;
	
	private ChartView m_chartView;
	
	private View m_activePane;
	
	private int m_currentGesture = -1;
	
	private GestureDetector m_flingGestureDetector;
	
	// #endregion
	
	// #region Listeners
	
	// Handles "go back" action.
	private final OnClickListener m_backActionListener = new OnClickListener()
	{
		public void onClick(View v)
		{
			bringOptionsPaneToView(m_rootOptionsPane);
		}
	};
	
	// #endregion
	// #endregion
	
	// #region Protected methods
	/*
	 * (non-Javadoc)
	 * 
	 * @see android.app.Activity#onCreate(android.os.Bundle)
	 */
	@Override
	protected void onCreate(Bundle savedInstanceState)
	{
		super.onCreate(savedInstanceState);
		// Prepares editor window.
		prepareWindowForView();
		// Set content to chart view editor from resources.
		setContentView(R.layout.chartview_editor);
		// Initialize chart view container.
		initContainer();
		// Initialize necessary components.
		initContent();
	}
	
	/*
	 * Catching back button press in order to prevent activity from closing.
	 */
	@Override
	public boolean onKeyDown(int keyCode, KeyEvent event)
	{
		switch(keyCode)
		{
			case KeyEvent.KEYCODE_BACK:
			{
				if(m_activePane != m_rootOptionsPane)
				{
					m_backActionListener.onClick(null);
					return true;
				}
				break;
			}
			case KeyEvent.KEYCODE_SEARCH:
			{
				zoomIn();
				return true;
			}
			case KeyEvent.KEYCODE_MENU:
			{
				View optionsPanel = (View)findViewById(R.id.optionsPane);
				if(optionsPanel.getVisibility() == View.VISIBLE)
				{
					optionsPanel.setVisibility(View.GONE);
				}
				else
				{
					optionsPanel.setVisibility(View.VISIBLE);
				}
				return true;
			}
				
		}
		return super.onKeyDown(keyCode, event);
	}
	
	// #endregion
	
	// #region Public methods
	/*
	 * (non-Javadoc)
	 * 
	 * @see android.app.Activity#onTouchEvent(android.view.MotionEvent)
	 */
	@Override
	public boolean onTouchEvent(MotionEvent event)
	{
		if(event.getAction() == MotionEvent.ACTION_DOWN)
		{
			m_circularGestureStarted = true;
		}
		
		if(event.getAction() == MotionEvent.ACTION_UP)
		{
			PointF[] gesturePoints = m_gesturePoints.toArray(new PointF[ 0 ]);
			
			// Determining center point.
			PointF center = null;
			float maxdist = 0;
			PointF point1 = null, point2 = null;
			PointF farPoint1 = null, farPoint2 = null;
			float dist = 0;
			for(int i = 0; i < gesturePoints.length - 1; i++)
			{
				for(int j = i + 1; j < gesturePoints.length; j++)
				{
					point1 = gesturePoints[i];
					point2 = gesturePoints[j];
					
					dist = getSquareDistance(point1, point2);
					if(dist > maxdist)
					{
						farPoint1 = point1;
						farPoint2 = point2;
						maxdist = dist;
					}
				}
			}
			if(farPoint1 != null && farPoint2 != null)
			{
				center = new PointF((farPoint1.x + farPoint2.x) / 2,
						(farPoint1.y + farPoint2.y) / 2);
			}
			else
			{
				m_circularGestureStarted = false;
				return m_flingGestureDetector.onTouchEvent(event);
			}
			// Getting gesture radius.
			double radius = 0;
			for(PointF point : gesturePoints)
			{
				radius += getDistance(center, point);
			}
			radius /= gesturePoints.length;
			
			// Determining radius deviation.
			double radiusDeviation = radius * RADIUS_TOLERANCE;
			
			boolean acceptGesture = true;
			// Validating gesture.
			for(PointF point : gesturePoints)
			{
				if(Math.abs(radius - getDistance(center, point)) > radiusDeviation)
				{
					acceptGesture = false;
					break;
				}
			}
			
			if(acceptGesture)
			{
				// Determining gesture's direction.
				int counter = 0;
				double al1 = 0, al2 = 0;
				for(int i = 0; i < gesturePoints.length - 1; i++)
				{
					point1 = gesturePoints[i];
					point2 = gesturePoints[i + 1];
					al1 = Math.atan2(point1.y - center.y, point1.x - center.x);
					al2 = Math.atan2(point2.y - center.y, point2.x - center.x);
					if(Math.abs(al1 - al2) > ANGLE_DEVIATION)
					{
						counter += al1 < al2 ? 1 : -1;
					}
				}
				applyCircularGesture(counter > 0);
			}
			m_circularGestureStarted = false;
			m_gesturePoints.clear();
			return acceptGesture ? true : m_flingGestureDetector.onTouchEvent(event);
		}
		
		if(m_circularGestureStarted && event.getAction() == MotionEvent.ACTION_MOVE)
		{
			// Saving gesture points for further gesture recognition.
			m_gesturePoints.add(new PointF(event.getX(), event.getY()));
		}
		// Letting gesture scanner decide.
		return m_flingGestureDetector.onTouchEvent(event);
	}
	
	// #endregion
	
	// #region Implementation
	
	/**
	 * Removes window title, sets window to fullscreen mode, locks window to
	 * landscape orientation.
	 */
	private void prepareWindowForView()
	{
		// Disable the title.
		requestWindowFeature(Window.FEATURE_NO_TITLE);
		// Force landscape mode.
		setRequestedOrientation(ActivityInfo.SCREEN_ORIENTATION_LANDSCAPE);
		// Show activity in full screen.
		getWindow().setFlags(WindowManager.LayoutParams.FLAG_FULLSCREEN,
				WindowManager.LayoutParams.FLAG_FULLSCREEN);
	}
	
	/**
	 * Initializes chart view container. Loads stores preferences.
	 */
	private void initContainer()
	{
		// Retrieve layout view from stored container.
		LinearLayout container = (LinearLayout)ChartView.inflate(this,
				R.layout.chartview_conainer, null);
		// Retrieve chart view from parent container.
		m_chartView = (ChartView)container.findViewById(R.id.chartView);
		// Initialize preferences from supplied view ID.
		m_preferencesHandler = new ChartPreferencesHandler(getIntent().getIntExtra(
				ChartPreferencesHandler.VIEW_ID, -1));
		// Load preferences from xml file.
		m_preferencesHandler.loadSettingsFromPreferences(this);
		// Transfer loaded preferences to chart view.
		m_preferencesHandler.transferToView(m_chartView);
		// Remove chart view from parent container in order to attach it to a new
		// one.
		container.removeView(m_chartView);
		// Attach chart view to a new container.
		LinearLayout chartPanel = (LinearLayout)findViewById(R.id.ChartPanel);
		chartPanel
				.addView(m_chartView, new LinearLayout.LayoutParams(
						ViewGroup.LayoutParams.FILL_PARENT,
						ViewGroup.LayoutParams.FILL_PARENT));
	}
	
	/**
	 * Initializes option panes and gesture helpers.
	 */
	private void initContent()
	{
		// Root options pane takes care of general options available to be set on
		// chart.
		m_activePane = m_rootOptionsPane = (OptionsPane)findViewById(R.id.rootOptionsPane);
		initRootOptionsPane(m_rootOptionsPane);
		// Palette options pane allows changing palette of currently selected chart
		// view.
		m_paletteOptionsPane = (OptionsPane)findViewById(R.id.palettesOptionsPane);
		initPaletteOptionsPane(m_paletteOptionsPane);
		// Legend options pane handles legend properties changes.
		m_legendOptionsPane = (OptionsPane)findViewById(R.id.legendOptionsPane);
		initLegendOptionsPane(m_legendOptionsPane);
		initFlingGestureDetector();
		initGestureToast();
	}
	
	private void initRootOptionsPane(OptionsPane optionsView)
	{
		// Shows palettes options pane.
		optionsView.addImageView("palettes", R.drawable.ico_themes,
				new OnClickListener()
				{
					public void onClick(View v)
					{
						m_legendOptionsPane.setTag(v.getTag());
						bringOptionsPaneToView(m_paletteOptionsPane);
					}
				});
		
		// Shows legend options pane.
		optionsView.addImageView("legend", R.drawable.ico_legend,
				new OnClickListener()
				{
					public void onClick(View v)
					{
						m_legendOptionsPane.setTag(v.getTag());
						bringOptionsPaneToView(m_legendOptionsPane);
					}
				}).setTag(m_chartView.getLegends().get(0));
		
		// Saves changed that were made.
		optionsView.addImageView("save", R.drawable.ico_save, new OnClickListener()
		{
			public void onClick(View v)
			{
				m_preferencesHandler.transferFromView(m_chartView);
				m_preferencesHandler
						.saveSettingsToPreferences(m_chartView.getContext());
				ChartEditorActivity.this.setResult(RESULT_OK, (new Intent()).putExtra(
						ChartPreferencesHandler.VIEW_ID, m_preferencesHandler.getViewID()));
				ChartEditorActivity.this.finish();
			}
		});
		// Reloads chart view from previously saved state.
		optionsView.addImageView("refresh", R.drawable.ico_default,
				new OnClickListener()
				{
					public void onClick(View v)
					{
						m_preferencesHandler.transferToView(m_chartView);
					}
				});
	}
	
	private void initPaletteOptionsPane(OptionsPane optionsView)
	{
		// Returns to root options pane.
		optionsView.addImageView("back", R.drawable.ico_up, m_backActionListener);
		// Changes palette to sleep.
		optionsView.addImageView("", R.drawable.sleep_palette).setTag(
				R.array.sleep_palette);
		optionsView.addImageView("", R.drawable.grayscale_palette).setTag(
				R.array.grayscale_palette);
		optionsView.addImageView("", R.drawable.grayscale_alternative_palette)
				.setTag(R.array.grayscal_alternative_palette);
		optionsView.addImageView("", R.drawable.solid_palette).setTag(
				R.array.solid_palette);
		optionsView.setOnItemClickListener(new OnItemClickListener()
		{
			public void onItemClick(AdapterView<?> parent, View view, int position,
					long id)
			{
				int[] targetPalette = getResources()
						.getIntArray((Integer)view.getTag());
				m_chartView.getChart().setPalette(new ChartPalette(targetPalette));
			}
		});
		
	}
	
	/**
	 * Fills legend options pane with available choices.
	 * 
	 * @param optionsView
	 */
	private void initLegendOptionsPane(OptionsPane optionsView)
	{
		// Returns to root options pane.
		optionsView.addImageView("back", R.drawable.ico_up, m_backActionListener);
		// Hides legend.
		optionsView.addImageView("hidden", R.drawable.ico_l_empty,
				new OnClickListener()
				{
					public void onClick(View v)
					{
						ChartLegend legend = (ChartLegend)m_legendOptionsPane.getTag();
						legend.setVisible(false);
					}
				});
		optionsView.addImageView("", R.drawable.ico_l_lu).setTag(
				new Enum[]{Dock.Top,Alignment.Near});
		optionsView.addImageView("", R.drawable.ico_l_u).setTag(
				new Enum[]{Dock.Top,Alignment.Center});
		optionsView.addImageView("", R.drawable.ico_l_ru).setTag(
				new Enum[]{Dock.Top,Alignment.Far});
		optionsView.addImageView("", R.drawable.ico_l_l).setTag(
				new Enum[]{Dock.Left,Alignment.Center});
		optionsView.addImageView("", R.drawable.ico_l_r).setTag(
				new Enum[]{Dock.Right,Alignment.Center});
		optionsView.addImageView("", R.drawable.ico_l_ld).setTag(
				new Enum[]{Dock.Bottom,Alignment.Near});
		optionsView.addImageView("", R.drawable.ico_l_d).setTag(
				new Enum[]{Dock.Bottom,Alignment.Center});
		optionsView.addImageView("", R.drawable.ico_l_rd).setTag(
				new Enum[]{Dock.Bottom,Alignment.Far});
		// Handles legend option setting.
		optionsView.setOnItemClickListener(new OnItemClickListener()
		{
			public void onItemClick(AdapterView<?> parent, View view, int position,
					long id)
			{
				ChartLegend legend = (ChartLegend)m_legendOptionsPane.getTag();
				Dock legendDock = (Dock)((Enum[])view.getTag())[0];
				Alignment legendAlignment = (Alignment)((Enum[])view.getTag())[1];
				legend.setDock(legendDock);
				legend.setAlignment(legendAlignment);
				legend.setVisible(true);
			}
		});
	}
	
	/**
	 * Initializes fling gesture detector used to track chart scroll gestures.
	 */
	private void initFlingGestureDetector()
	{
		m_flingGestureDetector = new GestureDetector(
				new GestureDetector.SimpleOnGestureListener()
				{
					@Override
					public boolean onFling(MotionEvent event1, MotionEvent event2,
							float velocityX, float velocityY)
					{
						int dx = (int)(event2.getX() - event1.getX());
						int dy = (int)(event2.getY() - event1.getY());
						// don't accept the fling if it's too short as it may
						// conflict with a button push.
						if(Math.abs(dx) > FLING_MAJOR_MOVE
								&& Math.abs(velocityX) > Math.abs(velocityY))
						{
							return applyHorizontalFling(velocityX > 0);
						}
						else if(Math.abs(dy) > FLING_MAJOR_MOVE
								&& Math.abs(velocityY) > Math.abs(velocityX))
						{
							return applyVerticalFling(velocityY > 0);
						}
						return false;
					}
				});
	}
	
	/**
	 * Initializes a toast message that appers when user gesture detected.
	 */
	private void initGestureToast()
	{
		// Initializing generic toast for user notifications.
		m_gestureToast = Toast.makeText(this, "", Toast.LENGTH_SHORT);
		m_gestureImage = new ImageView(this);
		m_gestureImage.setScaleType(ImageView.ScaleType.MATRIX);
		m_gestureToast.setView(m_gestureImage);
	}
	
	/**
	 * Sets Visibility of passed options pane to Visible. Hides the rest of views.
	 * 
	 * @param pane
	 */
	private void bringOptionsPaneToView(OptionsPane pane)
	{
		LinearLayout optionsPanel = (LinearLayout)findViewById(R.id.optionsPane);
		for(int i = 0; i < optionsPanel.getChildCount(); i++)
		{
			optionsPanel.getChildAt(i).setVisibility(View.GONE);
		}
		pane.setVisibility(View.VISIBLE);
		m_activePane = pane;
	}
	
	/**
	 * Gets the square distance between 2 points. Used for circular gesture
	 * detection.
	 * 
	 * @param p1 starting point.
	 * @param p2 ending point.
	 * @return square distance in between specified points.
	 */
	private float getSquareDistance(PointF p1, PointF p2)
	{
		return (p1.x - p2.x) * (p1.x - p2.x) + (p1.y - p2.y) * (p1.y - p2.y);
	}
	
	/**
	 * Gets the distance between 2 points. Used for circular gesture detection.
	 * 
	 * @param p1 starting point.
	 * @param p2 ending point.
	 * @return square distance in between specified points.
	 */
	private float getDistance(PointF p1, PointF p2)
	{
		return (float)Math.sqrt(getSquareDistance(p1, p2));
	}
	
	/**
	 * Zooms both axes depending on gesture direction.
	 * 
	 * @param isClockwise
	 */
	private void applyCircularGesture(boolean isClockwise)
	{
		if(isClockwise)
		{
			zoomIn();
		}
		else
		{
			zoomOut();
		}
	}
	
	/**
	 * @param isUpToBottom
	 * @return
	 */
	private boolean applyVerticalFling(boolean isUpToBottom)
	{
		showGestureToast(isUpToBottom ? SCROLL_DOWN_GESTURE : SCROLL_UP_GESTURE);
		return scrollAxis(m_chartView.getChart().getAreas().get(0)
				.getDefaultYAxis(), !isUpToBottom);
	}
	
	/**
	 * @param isRightToLeft
	 * @return
	 */
	private boolean applyHorizontalFling(boolean isRightToLeft)
	{
		showGestureToast(isRightToLeft ? SCROLL_RIGHT_GESTURE : SCROLL_LEFT_GESTURE);
		return scrollAxis(m_chartView.getChart().getAreas().get(0)
				.getDefaultXAxis(), isRightToLeft);
	}
	
	private boolean scrollAxis(ChartAxis axis, boolean isPositiveDirection)
	{
		ChartAxisScale axisScale = axis.getScale();
		
		if(axisScale.getZoomSize() != null)
		{
			int offsetVector = isPositiveDirection ? -1 : 1;
			double visibleMinimum = axisScale.getVisibleMinimum();
			double visibleMaximum = axisScale.getVisibleMaximum();
			double offset = (visibleMaximum - visibleMinimum) * AXIS_SHIFT_PORTION;
			double scroll = visibleMinimum + offset * offsetVector;
			
			scroll = MathUtils.clamp(scroll, axisScale.getRealMinimum(), axisScale
					.getRealMaximum()
					- axisScale.getZoomSize());
			
			axisScale.scroll(scroll);
			
			return true;
		}
		return false;
	}
	
	/**
	 * Zooms in currently edited chart area.
	 */
	private void zoomIn()
	{
		ChartAxisScale xAxisScale = m_chartView.getChart().getAreas().get(0)
				.getDefaultXAxis().getScale();
		ChartAxisScale yAxisScale = m_chartView.getChart().getAreas().get(0)
				.getDefaultYAxis().getScale();
		xAxisScale.mulZoom(1.0 / ZOOM_SCALE);
		yAxisScale.mulZoom(1.0 / ZOOM_SCALE);
		showGestureToast(ZOOM_IN_GESTURE);
	}
	
	/**
	 * Zooms out chart area that is currently being edited.
	 */
	private void zoomOut()
	{
		ChartAxisScale xAxisScale = m_chartView.getChart().getAreas().get(0)
				.getDefaultXAxis().getScale();
		ChartAxisScale yAxisScale = m_chartView.getChart().getAreas().get(0)
				.getDefaultYAxis().getScale();
		xAxisScale.mulZoom(ZOOM_SCALE);
		yAxisScale.mulZoom(ZOOM_SCALE);
		showGestureToast(ZOOM_OUT_GESTURE);
	}
	
	private void showGestureToast(int gestureID)
	{
		if(gestureID != m_currentGesture)
		{
			// Retrieving image view matrix.
			Matrix imageMatrix = m_gestureImage.getImageMatrix();
			if(imageMatrix == null)
			{
				imageMatrix = new Matrix();
				m_gestureImage.setImageMatrix(imageMatrix);
			}
			// Resetting any existing rotations of toast image.
			imageMatrix.setRotate(0);
			
			switch(gestureID)
			{
				case ZOOM_IN_GESTURE:
					m_gestureImage.setImageResource(R.drawable.ico_zoom_in);
					break;
				case ZOOM_OUT_GESTURE:
					m_gestureImage.setImageResource(R.drawable.ico_zoom_out);
					break;
				case SCROLL_LEFT_GESTURE:
					m_gestureImage.setImageResource(R.drawable.ico_scroll_left);
					break;
				case SCROLL_RIGHT_GESTURE:
					m_gestureImage.setImageResource(R.drawable.ico_scroll_right);
					break;
				case SCROLL_UP_GESTURE:
					imageMatrix.setRotate(90, m_gestureImage.getMeasuredWidth() / 2,
							m_gestureImage.getMeasuredWidth() / 2);
					m_gestureImage.setImageResource(R.drawable.ico_scroll_left);
					break;
				case SCROLL_DOWN_GESTURE:
					imageMatrix.setRotate(90, m_gestureImage.getMeasuredWidth() / 2,
							m_gestureImage.getMeasuredWidth() / 2);
					m_gestureImage.setImageResource(R.drawable.ico_scroll_right);
					break;
				default:
					throw new UnsupportedOperationException("Gesture ID " + gestureID
							+ " is undefined");
			}
			// Saving current gesture to prevent similar toasts to recur.
			m_currentGesture = gestureID;
			m_gestureToast.show();
		}
	}
	// #endregion
}
