// #region Copyright
// Copyright ArtfulBits Inc. 2005 - 2010. All rights reserved.
// 
// Use of this code is subject to the terms of our license.
// A copy of the current license can be obtained at any time by e-mailing
// info@artfulbits.com. Re-distribution in any form is strictly
// prohibited. Any infringement will be prosecuted under applicable laws.
// #endregion
package aiCharts.Demo.Financial.UI;

import java.util.ArrayList;

import com.artfulbits.aiCharts.ChartView;
import com.artfulbits.aiCharts.Types.ChartTypes;

import aiCharts.Demo.Financial.R;
import aiCharts.Demo.Financial.Utils.ChartPreferencesHandler;
import android.content.Context;
import android.view.View;
import android.view.ViewGroup;
import android.widget.BaseAdapter;

public class ChartViewAdapter extends BaseAdapter
{
	// #region Members
	private static final String COLUMN_SEPARATOR = "/";

	// Execution context. Used to inflate chart view container from resources.
	private Context m_context;

	private String[][] m_seriesHash;

	// Caching views in order to prevent unnecessary SQL queries.
	private ArrayList< View > m_containersCache = new ArrayList< View >();

	// #endregion

	// #region Constructor
	public ChartViewAdapter( Context context, final String[][] seriesHash )
	{
		super();
		m_context = context;
		m_seriesHash = seriesHash;
		// Building chart view containers cache.
		rebuildViewCache();
	}

	// #endregion

	// #region Public methods
	/*
	 * (non-Javadoc)
	 * @see android.widget.Adapter#getCount()
	 */
	@Override
	public int getCount()
	{
		return m_seriesHash.length;
	}

	/*
	 * (non-Javadoc)
	 * @see android.widget.Adapter#getItem(int)
	 */
	@Override
	public Object getItem( int position )
	{
		return m_seriesHash[ position ][ 0 ];
	}

	/*
	 * (non-Javadoc)
	 * @see android.widget.Adapter#getItemId(int)
	 */
	@Override
	public long getItemId( int position )
	{
		return getItem( position ).hashCode();
	}

	/*
	 * (non-Javadoc)
	 * @see android.widget.Adapter#getView(int, android.view.View,
	 * android.view.ViewGroup)
	 */
	@Override
	public View getView( int position, View convertView, ViewGroup parent )
	{
		return m_containersCache.get( position );
	}

	public void rebuildViewCache()
	{
		m_containersCache.clear();
		for( int i = 0; i < m_seriesHash.length; i++ )
		{
			m_containersCache.add( getContainer( i, m_seriesHash[ i ] ) );
		}
	}

	// #endregion

	// #region Implementation
	private View getContainer( int containerIndex, String[] seriesMappings )
	{
		View container = ( View )ChartView.inflate( m_context, R.layout.chartview_conainer, null );
		// Retrieving chart view from container.
		ChartView chartView = ( ChartView )container.findViewById( R.id.chartView );

		ChartPreferencesHandler prefsHndl = new ChartPreferencesHandler( containerIndex );
		// Loading previously stored preferences.

		if( !prefsHndl.loadSettingsFromPreferences( m_context ) )
		{
			prefsHndl.transferFromView( chartView );
		}

		if( !prefsHndl.valid() )
		{
			// Reserving arrays for series and column names.
			if( seriesMappings[ 0 ].equals( ChartTypes.HiLoName )
			    || seriesMappings[ 0 ].equals( ChartTypes.BubbleName ) )
			{
				prefsHndl.columnNames = new String[ 1 ];
				prefsHndl.seriesTypes = new String[ 1 ];

				prefsHndl.seriesTypes[ 0 ] = seriesMappings[ 0 ];
				prefsHndl.columnNames[ 0 ] = seriesMappings[ 1 ] + COLUMN_SEPARATOR + seriesMappings[ 2 ];
			}
			else if( seriesMappings[ 0 ].equals( ChartTypes.CandleStickName )
			    || seriesMappings[ 0 ].equals( ChartTypes.HiLoOpenCloseName ) )
			{
				prefsHndl.columnNames = new String[ 1 ];
				prefsHndl.seriesTypes = new String[ 1 ];

				prefsHndl.seriesTypes[ 0 ] = seriesMappings[ 0 ];
				prefsHndl.columnNames[ 0 ] = seriesMappings[ 1 ] + COLUMN_SEPARATOR + seriesMappings[ 2 ]
				    + COLUMN_SEPARATOR + seriesMappings[ 3 ] + COLUMN_SEPARATOR + seriesMappings[ 4 ];
			}
			else
			{
				prefsHndl.columnNames = new String[ seriesMappings.length - 1 ];
				prefsHndl.seriesTypes = new String[ seriesMappings.length - 1 ];

				for( int i = 1; i < seriesMappings.length; i++ )
				{
					prefsHndl.columnNames[ i - 1 ] = seriesMappings[ i ];
					prefsHndl.seriesTypes[ i - 1 ] = seriesMappings[ 0 ];
				}
			}
			prefsHndl.palette = chartView.getChart().getPalette().getValues();
		}
		// Saving retrieved series and column values to preferences.
		prefsHndl.saveSettingsToPreferences( m_context );

		// Transferring accommodated setting to chart view.
		prefsHndl.transferToView( chartView );

		return container;
	}
	// #endregion
}
