// #region Copyright
// Copyright ArtfulBits Inc. 2005 - 2010. All rights reserved.
// 
// Use of this code is subject to the terms of our license.
// A copy of the current license can be obtained at any time by e-mailing
// info@artfulbits.com. Re-distribution in any form is strictly
// prohibited. Any infringement will be prosecuted under applicable laws.
// #endregion
package aiCharts.Demo.Financial.UI;

import android.content.Context;
import android.util.AttributeSet;
import android.view.View;
import android.widget.HorizontalScrollView;
import android.widget.ImageView;
import android.widget.LinearLayout;
import android.widget.AdapterView.OnItemClickListener;
import android.widget.ImageView.ScaleType;

/**
 * Using options pane to implement carousel-like panel.
 * 
 * @author pturchenko
 */
public class OptionsPane extends HorizontalScrollView
{
	// #region Members
	/**
	 * Children hosting linear layout.
	 */
	private LinearLayout m_host = new LinearLayout(getContext());
	
	/**
	 * Callback for child item click.
	 */
	private OnItemClickListener m_itemsClickHandler;
	
	/**
	 * Callback for single item click.
	 */
	private OnClickListener m_itemClickHandler = new OnClickListener()
	{
		public void onClick(View v)
		{
			if(m_itemsClickHandler != null)
			{
				// Notifying subscriber about click on the target item.
				m_itemsClickHandler.onItemClick(null, v, OptionsPane.this
						.getViewIndex(v), v.getTag().hashCode());
			}
		}
	};
	
	// #endregion
	
	// #region Constructors
	public OptionsPane(Context context, AttributeSet attrs)
	{
		super(context, attrs);
	}
	
	// #endregion
	
	// #region Public methods
	
	/**
	 * Adds image view to the options pane.
	 * 
	 * @param caption string representation of image. Saved as tag internally.
	 * @param iconId resource id for the corresponding image.
	 * @param clickHandler callback for the click handler.
	 */
	public ImageView addImageView(String caption, int iconId,
			OnClickListener clickHandler)
	{
		ImageView image = new ImageView(getContext());
		image.setBackgroundResource(iconId);
		image.setTag(caption);
		image.setScaleType(ScaleType.CENTER_CROP);
		if(clickHandler != null)
		{
			image.setOnClickListener(clickHandler);
		}
		else
		{
			image.setOnClickListener(m_itemClickHandler);
		}
		m_host.addView(image);
		return image;
	}
	
	/**
	 * Adds image view to the options pane.
	 * 
	 * @param caption
	 * @param iconId
	 */
	public ImageView addImageView(String caption, int iconId)
	{
		return addImageView(caption, iconId, null);
	}
	
	public void setOnItemClickListener(OnItemClickListener itemClickHandler)
	{
		m_itemsClickHandler = itemClickHandler;
	}
	
	public OnItemClickListener getOnItemClickListener()
	{
		return m_itemsClickHandler;
	}
	
	// #endregion
	
	// #region Protected methods
	@Override
	protected void onAttachedToWindow()
	{
		m_host.setPadding(0, 0, 0, 10);
		// Set hosting view for represented items.
		this.addView(m_host);
		super.onAttachedToWindow();
	}
	
	// #endregion
	
	// #region Implementation
	/**
	 * Gets the index of target item.
	 * 
	 * @param view target view.
	 * @return either zero based index of target view or -1 if the view does not
	 * exit.
	 */
	private int getViewIndex(View view)
	{
		int childrenCount = m_host.getChildCount();
		for(int i = 0; i < childrenCount; i++)
		{
			if(view == m_host.getChildAt(i))
			{
				return i;
			}
		}
		return -1;
	}
	// #endregion
}
