// #region Copyright
// Copyright ArtfulBits Inc. 2005 - 2010. All rights reserved.
// 
// Use of this code is subject to the terms of our license.
// A copy of the current license can be obtained at any time by e-mailing
// info@artfulbits.com. Re-distribution in any form is strictly
// prohibited. Any infringement will be prosecuted under applicable laws.
// #endregion
package aiCharts.Demo;

import com.artfulbits.aiCharts.Types.ChartTypes;
import com.artfulbits.aiCharts.ChartView;

import aiCharts.Demo.UI.ChartViewAdapter;
import aiCharts.Demo.Utils.ChartPreferencesHandler;
import android.app.AlertDialog;
import android.app.Dialog;
import android.app.ListActivity;
import android.app.AlertDialog.Builder;
import android.content.Intent;
import android.os.Bundle;
import android.view.Menu;
import android.view.MenuInflater;
import android.view.MenuItem;
import android.view.View;
import android.view.Window;

import android.widget.ListView;

/**
 * Main activity. Displays predefined charts in a list manner. Allows editing
 * each chart settings by simple click.
 * 
 * @author pturchenko
 */
public class aiChartDemo extends ListActivity
{
	// #region Members
	private static final String[][] m_seriesHash = new String[][]{
			new String[]{ChartTypes.StackedBarName,"Y7","Y8","Y9"},
			new String[]{ChartTypes.SplineAreaName,"Y1","Y2"},
			new String[]{ChartTypes.SplineName,"Y1","Y2","Y3","Y4"},
			new String[]{ChartTypes.PieName,"Y9"},
			new String[]{ChartTypes.ColumnName,"Y4","Y5"},
			new String[]{ChartTypes.LineName,"Y1","Y2","Y3"}};
	
	private ChartViewAdapter m_viewAdapter;
	
	// #endregion
	
	// #region Public methods
	/** Called when the activity is first created. */
	@Override
	public void onCreate(Bundle savedInstanceState)
	{
		super.onCreate(savedInstanceState);
		requestWindowFeature(Window.FEATURE_NO_TITLE);
		setContentView(R.layout.main);
		m_viewAdapter = new ChartViewAdapter(this, m_seriesHash);
		this.setListAdapter(m_viewAdapter);
	}
	
	/*
	 * (non-Javadoc)
	 * 
	 * @see android.app.Activity#onCreateOptionsMenu(android.view.Menu)
	 */
	@Override
	public boolean onCreateOptionsMenu(Menu menu)
	{
		MenuInflater menuInflater = new MenuInflater(this);
		menuInflater.inflate(R.menu.main, menu);
		return super.onCreateOptionsMenu(menu);
	}
	
	@Override
	public boolean onMenuItemSelected(int featureId, MenuItem item)
	{
		switch(item.getItemId())
		{
			case R.id.defaults_action:
				ChartPreferencesHandler.clearPreferences(this);
				m_viewAdapter.rebuildViewCache();
				getListView().invalidateViews();
				return true;
			case R.id.about_action:
				showDialog(R.id.about_action);
				return true;
		}
		return super.onMenuItemSelected(featureId, item);
	}
	
	// #endregion
	
	// #region Protected methods
	/*
	 * (non-Javadoc)
	 * 
	 * @see android.app.Activity#onCreateDialog(int)
	 */
	@Override
	protected Dialog onCreateDialog(int id)
	{
		Dialog result = null;
		Builder builder;
		
		switch(id)
		{
			case R.id.about_action:
				builder = new AlertDialog.Builder(this);
				builder.setTitle(R.string.about_menu_item_title);
				builder.setMessage(R.string.dlg_about_msg);
				builder.setPositiveButton(R.string.dlg_ok_btn_title, null);
				result = builder.create();
				break;
			
			default:
				result = super.onCreateDialog(id);
				break;
		}
		
		return result;
	}
	
	/* (non-Javadoc)
	 * @see android.app.ListActivity#onListItemClick(android.widget.ListView, android.view.View, int, long)
	 */
	@Override
	protected void onListItemClick(ListView parent, View targetView,
			int position, long id)
	{
		Intent editChartViewIntent = new Intent(this, ChartEditorActivity.class);
		editChartViewIntent.putExtra(ChartPreferencesHandler.VIEW_ID, position);
		startActivityForResult(editChartViewIntent, 0);
		super.onListItemClick(parent, targetView, position, id);
	}
	
	/* (non-Javadoc)
	 * @see android.app.Activity#onActivityResult(int, int, android.content.Intent)
	 */
	@Override
	protected void onActivityResult(int requestCode, int resultCode, Intent data)
	{
		super.onActivityResult(requestCode, resultCode, data);
		
		if(resultCode == RESULT_OK)
		{
			int viewId = data.getIntExtra(ChartPreferencesHandler.VIEW_ID, -1);
			ChartPreferencesHandler preferencesHandler = new ChartPreferencesHandler(
					viewId);
			preferencesHandler.loadSettingsFromPreferences(this);
			ChartView chartView = (ChartView)getListAdapter().getView(viewId, null,
					null).findViewById(R.id.chartView);
			preferencesHandler.transferToView(chartView);
		}
		
	}
	// #endregion
	
}
